@@ -11,8 +11,8 @@
 #include <qpushbutton.h>
 
 #include <kdebug.h>
-#include <kapp.h>
-#include <kstddirs.h>
+#include <kapplication.h>
+#include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <ktoolbar.h>
 #include <kmainwindow.h>
@@ -26,6 +26,7 @@
 #include <kstdaction.h>
 #include <kstdgameaction.h>
 #include <kaudioplayer.h>
+#include <kscoredialog.h>
 
 #include "toplevel.h"
 #include "ledmeter.h"
@@ -35,7 +36,6 @@
 #include "toplevel.moc"
 
 #include <X11/Xlib.h>
-#include <klocale.h>
 
 #define SB_SCORE	1
 #define SB_LEVEL	2
@@ -68,14 +68,14 @@ SLevel levels[MAX_LEVELS] =
     { 5, 1.0 }
 };
 
-const char *soundEvents[] = 
+const char *soundEvents[] =
 {
     "ShipDestroyed",
     "RockDestroyed",
     0
 };
 
-const char *soundDefaults[] = 
+const char *soundDefaults[] =
 {
     "Explosion.wav",
     "ploop.wav",
@@ -89,7 +89,7 @@ const char *soundDefaults[] =
 Arts::SimpleSoundServer *soundServer = 0;
 #endif
 
- 
+
 KAstTopLevel::KAstTopLevel() : KMainWindow(0)
 {
     setCaption("");
@@ -265,8 +265,6 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
     powerMeter->setFixedSize( 200, 12 );
     hbd->addWidget( powerMeter );
 
-    highscore = new HighscoreList( this );
-
     accel = new KAccel( this );
     actions.insert( "Thrust", Thrust );
     accel->insertItem( i18n("Thrust"), "Thrust", Qt::Key_Up );
@@ -302,6 +300,8 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
 #endif
 
     readSettings();
+    
+    applyKeys();
 }
 
 KAstTopLevel::~KAstTopLevel()
@@ -312,6 +312,19 @@ KAstTopLevel::~KAstTopLevel()
 #endif
 }
 
+void KAstTopLevel::applyKeys()
+{
+   keycodes.clear();
+   for(QMapIterator<QString, Action> it = actions.begin();
+       it != actions.end(); ++it)
+   {
+      QString actionName = it.key();
+      Action a = it.data();
+      int key = accel->shortcut(actionName);
+      keycodes[key] = a;
+   }
+}
+
 void KAstTopLevel::initKAction()
 {
     KStdGameAction::gameNew( this, SLOT( slotNewGame() ), actionCollection() );
@@ -344,7 +357,7 @@ void KAstTopLevel::readSettings()
     }
 
     sound = config->readBoolEntry( "PlaySounds", true );
-	
+
     config->setGroup( "Preferences" );
 
     showHiscores = config->readBoolEntry( "showHiscores", false );
@@ -376,15 +389,13 @@ return; // remove this and the above when the sound below is working correctly
 
 void KAstTopLevel::keyPressEvent( QKeyEvent *event )
 {
-    QString id = accel->findKey( event->key() );
-
-    if ( id.isEmpty() )
+    QMapIterator<int, Action> it = keycodes.find( event->key() );
+    if (it == keycodes.end())
     {
-        event->ignore();
-        return;
+       event->ignore();
+       return;
     }
-
-    Action a = actions[ id ];
+    Action a = it.data();
 
     switch ( a )
     {
@@ -425,15 +436,13 @@ void KAstTopLevel::keyPressEvent( QKeyEvent *event )
 
 void KAstTopLevel::keyReleaseEvent( QKeyEvent *event )
 {
-    QString id = accel->findKey( event->key() );
-
-    if ( id.isEmpty() )
+    QMapIterator<int, Action> it = keycodes.find( event->key() );
+    if (it == keycodes.end())
     {
-        event->ignore();
-        return;
+       event->ignore();
+       return;
     }
-
-    Action a = actions[ id ];
+    Action a = it.data();
 
     switch ( a )
     {
@@ -519,7 +528,7 @@ void KAstTopLevel::slotNewGame()
     view->setRockSpeed( levels[0].rockSpeed );
     view->addRocks( levels[0].nrocks );
     view->showText( i18n( "Press %1 to launch." )
-                    .arg(KAccel::keyToString(accel->currentKey("Launch"), true)),
+                    .arg(accel->shortcut("Launch").toString()),
                     yellow );
     waitShip = true;
     isPaused = false;
@@ -527,7 +536,9 @@ void KAstTopLevel::slotNewGame()
 
 void KAstTopLevel::slotQuit()
 {
+    XAutoRepeatOn( qt_xdisplay() );
     kapp->quit();
+    delete this;
 }
 
 void KAstTopLevel::slotShipKilled()
@@ -541,7 +552,7 @@ void KAstTopLevel::slotShipKilled()
     {
         waitShip = true;
         view->showText( i18n( "Ship Destroyed. Press %1 to launch.")
-                        .arg(KAccel::keyToString(accel->currentKey("Launch"), true)),
+                        .arg(accel->shortcut("Launch").toString()),
                         yellow );
     }
     else
@@ -549,7 +560,15 @@ void KAstTopLevel::slotShipKilled()
         view->showText( i18n("Game Over!"), red );
         view->endGame();
 	doStats();
-        highscore->addEntry( score, level, showHiscores );
+	KScoreDialog d(KScoreDialog::Name | KScoreDialog::Level | KScoreDialog::Score, this);
+        KScoreDialog::FieldInfo scoreInfo;
+        scoreInfo[KScoreDialog::Level].setNum(level);
+        
+        if (d.addScore(score, scoreInfo) || showHiscores)
+        {
+           // Show highscore and ask for name.	
+           d.exec();
+        }
     }
 }
 
@@ -590,6 +609,7 @@ void KAstTopLevel::slotRocksRemoved()
 void KAstTopLevel::slotKeyConfig()
 {
     KKeyDialog::configureKeys( accel, true, this );
+    applyKeys();
 }
 
 void KAstTopLevel::slotPref()
@@ -602,7 +622,8 @@ void KAstTopLevel::slotPref()
 
 void KAstTopLevel::slotShowHighscores()
 {
-    highscore->show();
+    KScoreDialog d(KScoreDialog::Name | KScoreDialog::Level | KScoreDialog::Score, this);
+    d.exec();
 }
 
 void KAstTopLevel::doStats()
