@@ -1,13 +1,15 @@
 /*
- *	--- view.cpp ---
+ * KAsteroids - Copyright (c) Martin R. Jones 1997
+ *
+ * Part of the KDE project
  */
 
 #include <stdlib.h>
 #include <math.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <qkeycode.h>
 #include <qaccel.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kglobal.h>
 #include <kconfig.h>
 
@@ -48,7 +50,7 @@ kas_animations [] =
     { ID_ROCK_LARGE,       "rock1/rock1%1.png",       32 },
     { ID_ROCK_MEDIUM,      "rock2/rock2%1.png",       32 },
     { ID_ROCK_SMALL,       "rock3/rock3%1.png",       32 },
-    { ID_SHIP,             "ship/ship%1.png",         32 },
+    { ID_SHIP,             "ship/ship%1.png",         64 },
     { ID_MISSILE,          "missile/missile.png",      1 },
     { ID_BIT,              "bits/bits%1.png",         16 },
     { ID_EXHAUST,          "exhaust/exhaust.png",      1 },
@@ -65,7 +67,7 @@ kas_animations [] =
 
 KAsteroidsView::KAsteroidsView( QWidget *parent, const char *name )
     : QWidget( parent, name ),
-      field(),
+      field(640, 440),
       view(&field,this)
 {
     view.setVScrollBarMode( QScrollView::AlwaysOff );
@@ -76,6 +78,7 @@ KAsteroidsView::KAsteroidsView( QWidget *parent, const char *name )
     powerups.setAutoDelete( true );
     exhaust.setAutoDelete( true );
 
+    field.setBackgroundColor(black);
     QPixmap pm( locate("sprite", IMG_BACKGROUND) );
     field.setBackgroundPixmap( pm );
 
@@ -182,8 +185,8 @@ void KAsteroidsView::pause( bool p )
 
 void KAsteroidsView::newShip()
 {
-    ship->move( width()/2, height()/2, 0 );
-    shield->move( width()/2, height()/2, 0 );
+    ship->move( field.width()/2, field.height()/2, 0 );
+    shield->move( field.width()/2, field.height()/2, 0 );
     ship->setVelocity( 0.0, 0.0 );
     shipDx = 0;
     shipDy = 0;
@@ -266,10 +269,12 @@ void KAsteroidsView::addRocks( int num )
     for ( int i = 0; i < num; i++ )
     {
         KRock *rock = new KRock( animation[ID_ROCK_LARGE], &field,
-                                 ID_ROCK_LARGE );
+                                 ID_ROCK_LARGE, krandom.getLong(2),
+				 krandom.getLong(2) ? -1 : 1 );
         double dx = (2.0 - krandom.getDouble()*4.0) * rockSpeed;
         double dy = (2.0 - krandom.getDouble()*4.0) * rockSpeed;
         rock->setVelocity( dx, dy );
+	rock->setFrame( krandom.getLong( rock->frameCount() ) );
         if ( dx > 0 )
         {
             if ( dy > 0 )
@@ -291,14 +296,21 @@ void KAsteroidsView::addRocks( int num )
 
 // - - -
 
-void KAsteroidsView::showText( const QString &text, const QColor &color )
+void KAsteroidsView::showText( const QString &text, const QColor &color, bool scroll )
 {
+//    textSprite->setTextFlags( AlignHCenter | AlignVCenter );
     textSprite->setText( text );
     textSprite->setColor( color );
 
-    textDy = TEXT_SPEED;
-
-    textSprite->move( (width()-textSprite->boundingRect().width()) / 2, -5 );
+    if ( scroll ) {
+	textSprite->move( (field.width()-textSprite->boundingRect().width()) / 2,
+			    -textSprite->boundingRect().height() );
+	textDy = TEXT_SPEED;
+    } else {
+	textSprite->move( (field.width()-textSprite->boundingRect().width()) / 2,
+			  (field.height()-textSprite->boundingRect().height()) / 2 );
+	textDy = 0;
+    }
     textSprite->show();
 }
 
@@ -328,7 +340,7 @@ void KAsteroidsView::timerEvent( QTimerEvent * )
 
     // move rocks forward
     for ( rock = rocks.first(); rock; rock = rocks.next() ) {
-        rock->setFrame( ( rock->frame()+1 ) % rock->frameCount() );
+        ((KRock *)rock)->nextFrame();
         wrapSprite( rock );
     }
 
@@ -361,15 +373,16 @@ void KAsteroidsView::timerEvent( QTimerEvent * )
     // move powerups and check for collision with player and missiles
     processPowerups();
 
-    if ( textSprite->visible() )
+    if ( textSprite->isVisible() )
     {
-        if ( textDy < 0 && textSprite->boundingRect().y() <= -5 )
+        if ( textDy < 0 &&
+	     textSprite->boundingRect().y() <= -textSprite->boundingRect().height() )
             textSprite->hide();
         else
         {
             textSprite->moveBy( 0, textDy );
         }
-        if ( textSprite->boundingRect().y() > height()/3 )
+        if ( textSprite->boundingRect().y() > (field.height()-textSprite->boundingRect().height())/2 )
             textDy = 0;
     }
 
@@ -464,18 +477,21 @@ void KAsteroidsView::rockHit( QCanvasItem *hit )
             if ( hit->rtti() == ID_ROCK_LARGE )
             {
                 nrock = new KRock( animation[ID_ROCK_MEDIUM], &field,
-                                   ID_ROCK_MEDIUM );
+                                   ID_ROCK_MEDIUM, krandom.getLong(2),
+				   krandom.getLong(2) ? -1 : 1 );
                 emit rockHit( 0 );
             }
             else
             {
                 nrock = new KRock( animation[ID_ROCK_SMALL], &field,
-                                   ID_ROCK_SMALL );
+                                   ID_ROCK_SMALL, krandom.getLong(2),
+				   krandom.getLong(2) ? -1 : 1 );
                 emit rockHit( 1 );
             }
 
             nrock->move( hit->x(), hit->y(), 0 );
             nrock->setVelocity( dx+addx[i]*rockSpeed+r, dy+addy[i]*rockSpeed+r );
+	    nrock->setFrame( krandom.getLong( nrock->frameCount() ) );
             nrock->show( );
             rocks.append( nrock );
         }
@@ -522,7 +538,7 @@ void KAsteroidsView::processMissiles()
 
     // if a missile has hit a rock, remove missile and break rock into smaller
     // rocks or remove completely.
-    QListIterator<KMissile> it(missiles);
+    QPtrListIterator<KMissile> it(missiles);
 
     for ( ; it.current(); ++it )
     {
@@ -557,7 +573,7 @@ void KAsteroidsView::processMissiles()
 
 void KAsteroidsView::processShip()
 {
-    if ( ship->visible() )
+    if ( ship->isVisible() )
     {
         if ( shieldOn )
         {
@@ -730,11 +746,11 @@ void KAsteroidsView::processShip()
                         shipDx-cosangle, shipDy-sinangle, 3 );
         }
 
-        ship->setFrame( shipAngle >> 1 );
+        ship->setFrame( shipAngle );
 
         if ( shootShip )
         {
-            if ( !shootDelay && missiles.count() < mShootCount + 2 )
+            if ( !shootDelay && (int)missiles.count() < mShootCount + 2 )
             {
               KMissile *missile = new KMissile( animation[ID_MISSILE], &field );
               missile->move( 21+ship->x()+cosangle*21,
@@ -778,7 +794,7 @@ void KAsteroidsView::processPowerups()
         // destroy it
 
         KPowerup *pup;
-        QListIterator<KPowerup> it( powerups );
+        QPtrListIterator<KPowerup> it( powerups );
 
         for( ; it.current(); ++it )
         {
