@@ -26,23 +26,24 @@
 #include <klocale.h>
 #include <kmenubar.h>
 #include <ksimpleconfig.h>
-#include <kstddirs.h>
-#include <kapp.h>
+#include <kstandarddirs.h>
+#include <kapplication.h>
 
 #include "gamewidget.h"
 #include "toplevel.h"
 #include "settings.h"
 #include "configbox.h"
+#include <kaccel.h>
 #include <kaction.h>
 #include <kstdaction.h>
+#include <kstdgameaction.h>
 #include <kdebug.h>
 
 extern Options settings;
 
 void AtomTopLevel::createMenu()
 {
-    game_highscore = new KAction(i18n("Sh&ow Highscore"), CTRL+Key_H, main,
-                                 SLOT (showHighscores ()), actionCollection(), "game_highscores");
+    KStdGameAction::highscores(main, SLOT(showHighscores()), actionCollection());
     game_exit = KStdAction::quit(this, SLOT(quitapp()), actionCollection(), "game_quit");
 
     KStdAction:: keyBindings(this, SLOT(configkeys()), actionCollection());
@@ -120,6 +121,7 @@ void AtomTopLevel::quitapp()
 {
     saveConfig();
     kapp->quit();
+    delete this;
 }
 
 bool AtomTopLevel::queryExit()
