@@ -2,21 +2,21 @@
 
   Copyright (C) 1999,2000 Jens Hoefkens
   jens@hoefkens.com
-  
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-  
+
 */
 
 #include "kbgtextview.moc"
@@ -27,7 +27,7 @@
 #include <kcmenumngr.h>
 #include <kfontdialog.h>
 #include <qfont.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 #include <iostream.h>
 
@@ -52,14 +52,13 @@ KBgTextView::~KBgTextView()
 }
 
 /*
- * Write the string l to the TextView and put the cursor at the end of 
+ * Write the string l to the TextView and put the cursor at the end of
  * the current text
  */
 void KBgTextView::write(const QString &l)
 {
-	append("<font face=\"" + font().family() + "\">" + l + "</font>");
-	scrollBy(0,99999);
-	viewport()->repaint();
+	append("<font face=\"" + font().family() + "\">" + l + "</font><br>");
+	scrollToBottom();
 }
 
 /*
@@ -71,14 +70,13 @@ void KBgTextView::clear()
 }
 
 /*
- * Open a font-selection dialog. 
+ * Open a font-selection dialog.
  */
 void KBgTextView::selectFont()
 {
 	QFont f = font();
 	KFontDialog::getFont(f, false, this, true);
 	setFont(f);
-	//clear();
 }
 
 /*
