@@ -19,7 +19,7 @@
   
 */
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <qstring.h>
 #include <klocale.h>
 #include <kaboutdata.h>
