@@ -1,6 +1,6 @@
 /* Yo Emacs, this -*- C++ -*-
 
-  Copyright (C) 1999,2000 Jens Hoefkens
+  Copyright (C) 1999-2001 Jens Hoefkens
   jens@hoefkens.com
 
   This program is free software; you can redistribute it and/or modify
@@ -25,8 +25,9 @@
 
 
 #define PROG_NAME      "kbackgammon"
-#define PROG_VERSION   "2.2.0"
-#define PROG_HOME      "http://backgammon.sourceforge.net/"
+#define PROG_VERSION   "2.5.0"
+#define PROG_HOME      "http://www.hoefkens.com/lnx/kbg.html"
 
+#define PROG_COOKIE    10500   // see also kdebug.areas
 
 #endif // __KBG_VERSION_H
