@@ -20,6 +20,7 @@
 #include <qlayout.h>
 #include <kgamemisc.h>
 #include "main.h"
+#include <kstatusbar.h>
 #include "kbattleship.moc"
 
 KBattleshipApp::KBattleshipApp(QWidget *, const char *name) : KMainWindow(0, name)
@@ -38,7 +39,7 @@ KBattleshipApp::KBattleshipApp(QWidget *, const char *name) : KMainWindow(0, nam
 	QString onePicCheck = locate("data", "kbattleship/pictures/hit.png");
 	if(picDirCheck.isEmpty() || onePicCheck.isEmpty())
 	{
-		KMessageBox::error(0L, i18n("You don't have KBattleship Pictures installed. The game cannot run without them!"));
+		KMessageBox::error(this, i18n("You don't have KBattleship Pictures installed. The game cannot run without them!"));
 		exit(0);
 	}
 	else
@@ -49,6 +50,10 @@ KBattleshipApp::~KBattleshipApp()
 {
 	if(m_config != 0)
 		saveOptions();
+	delete m_aiPlayer;
+	delete m_ownshiplist;
+	delete m_enemyshiplist;
+	delete m_sound;
 }
 
 void KBattleshipApp::init()
@@ -79,16 +84,16 @@ void KBattleshipApp::initStatusBar()
 
 void KBattleshipApp::initActions()
 {
-	m_gameServerConnect = new KAction(i18n("&Connect to server"), "connect_no", Key_F2, this, SLOT(slotServerConnect()), actionCollection(), "serverconnect");
-	m_gameNewServer = new KAction(i18n("&Start server"), "network", Key_F3, this, SLOT(slotNewServer()), actionCollection(), "newserver");
+	m_gameServerConnect = new KAction(i18n("&Connect to Server"), "connect_no", Key_F2, this, SLOT(slotServerConnect()), actionCollection(), "serverconnect");
+	m_gameNewServer = new KAction(i18n("&Start Server"), "network", Key_F3, this, SLOT(slotNewServer()), actionCollection(), "newserver");
 	m_gameSingle = new KAction(i18n("S&ingle Player"), "gear", Key_F4, this, SLOT(slotSinglePlayer()), actionCollection(), "singleplayer");
 	m_gameQuit = KStdAction::quit( this, SLOT(slotGameQuit()), actionCollection(), "gamequit");
 	(void) new KAction(i18n("&Highscore"), "view_text", Key_F10, this, SLOT(slotHighscore()), actionCollection(), "highscore");
 	m_gameEnemyInfo = new KAction(i18n("&Enemy Info..."), "view_text", Key_F11, this, SLOT(slotEnemyClientInfo()), actionCollection(), "enemyinfo");
 
 	m_viewStatusBar = KStdAction::showStatusbar(this, SLOT(slotViewStatusBar()), actionCollection());
-	m_configSound = new KToggleAction(i18n("&Play sounds"), 0, this, SLOT(slotConfigSound()), actionCollection(), "configsound");
-	m_configGrid = new KToggleAction(i18n("&Show grid"), 0, this, SLOT(slotShowGrid()), actionCollection(), "showgrid");
+	m_configSound = new KToggleAction(i18n("&Play Sounds"), 0, this, SLOT(slotConfigSound()), actionCollection(), "configsound");
+	m_configGrid = new KToggleAction(i18n("&Show Grid"), 0, this, SLOT(slotShowGrid()), actionCollection(), "showgrid");
 
 	m_gameEnemyInfo->setEnabled(false);
 	createGUI();
@@ -136,7 +141,7 @@ void KBattleshipApp::initView()
 
 	m_ownshiplist = new KShipList();
 	m_enemyshiplist = new KShipList();
-	m_score = new KHighscoreDialog(0L);
+	m_score = new KHighscoreDialog(this);
 
 	m_view->startDrawing();
 	setFocusProxy(m_view);
@@ -593,7 +598,7 @@ void KBattleshipApp::slotHighscore()
 
 void KBattleshipApp::slotEnemyClientInfo()
 {
-	KInfoDialog *m_info = new KInfoDialog(0L);
+	KInfoDialog *m_info = new KInfoDialog(this);
 
 	m_info->lbl_clientIdentfier->setText(m_enemyClient);
 	m_info->lbl_clientVersion->setText(m_enemyClientVersion);
