@@ -19,7 +19,7 @@
 
 #include <kmessagebox.h>
 #include <kdebug.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kglobal.h>
@@ -28,11 +28,11 @@
 #include <khelpmenu.h>
 #include <kaction.h>
 #include <kstdaction.h>
-#include <klocale.h>
 
 #include "kbbgame.h"
 #include "util.h"
 #include "version.h"
+#include <kstatusbar.h>
 
 /*
   Names of pixmap files.
