@@ -9,7 +9,7 @@
 //
 
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 
