@@ -10,10 +10,14 @@ Background::Background()
 }
 
 Background::~Background() {
+  delete sourceImage;
+  delete backgroundImage;
+  delete backgroundPixmap;
+  delete backgroundShadowPixmap;
 
 }
 
-bool Background::load(const char *file, short width, short height) {
+bool Background::load(const QString &file, short width, short height) {
  
   w=width;
   h=height; 
