@@ -1,6 +1,6 @@
 
 #include <stdlib.h> 
-#include <kapp.h>
+#include <kapplication.h>
 #include <qdir.h>
 #include <qpixmap.h>
 #include <qimage.h>
@@ -65,8 +65,10 @@ Editor::Editor
     drawFrame->setMaximumSize( 32767, 32767 );
     drawFrame->setFocusPolicy( QWidget::NoFocus );
     drawFrame->setBackgroundMode( QWidget::PaletteBackground );
+#if QT_VERSION < 300  
     drawFrame->setFontPropagation( QWidget::NoChildren );
     drawFrame->setPalettePropagation( QWidget::NoChildren );
+#endif
     drawFrame->setFrameStyle( 49 );
     drawFrame->setMouseTracking(true);
 
@@ -87,7 +89,7 @@ Editor::Editor
    tiles.loadTileset(preferences.tileset());
 
    // tell the user what we do
-   setCaption(kapp->makeStdCaption(i18n("Edit board layout")));
+   setCaption(kapp->makeStdCaption(i18n("Edit Board Layout")));
 
 
    connect( drawFrame, SIGNAL(mousePressed(QMouseEvent *) ),
