@@ -4,12 +4,12 @@
 #include <stdlib.h>
 
 #include <qlabel.h>
-#include <qpushbt.h>
+#include <qpushbutton.h>
 #include <qlineedit.h>
 
 #include <klocale.h>
 #include <kglobal.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 GameNum::GameNum
 (
@@ -51,7 +51,7 @@ GameNum::GameNum
 	canBtn->setAutoResize( FALSE );
 
 
-	setCaption(kapp->makeStdCaption(i18n("New game")));
+	setCaption(kapp->makeStdCaption(i18n("New Game")));
 
 	resize( 220,130 );
 	setFixedSize(220,130);
