@@ -4,17 +4,16 @@
 
 
 #include <qlabel.h>
-#include <qpushbt.h>
+#include <qpushbutton.h>
 #include <qfileinfo.h>
 #include <kmessagebox.h>
 #include "kglobal.h"
 #include "klocale.h"
-#include <kstddirs.h>                       
+#include <kstandarddirs.h>                       
 #include <kiconloader.h>
 #include <qlineedit.h>
 #include <qcombobox.h>
-#include <qpushbt.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 static const QString highScoreMagic1_0 = "kmahjongg-scores-v1.0";
 static const QString highScoreMagic1_1 = "kmahjongg-scores-v1.1";  
@@ -497,9 +496,9 @@ void HighScore::reset(void) {
 
         int res=KMessageBox::warningYesNo(this,
                         i18n("Resetting the high scores will "
-                                           "remove all high score entries\n"
-                                           "both in memory an on disk. Do "
-					   "you want to proceede?"),
+                                           "remove all high score entries "
+                                           "both in memory and on disk. Do "
+					   "you wish to proceed?"),
                         		   i18n("Reset high scores" ));
         if (res != 1)
                 return ;   
