@@ -1,6 +1,6 @@
 /*
 
-    $Id: kmahjongg.cpp,v 1.58.2.1 2001/09/13 21:31:09 mhaertjen Exp $
+    $Id: kmahjongg.cpp,v 1.62 2002/03/17 15:28:22 mlaurent Exp $
 
     kmahjongg, the classic mahjongg game for KDE project
 
@@ -28,7 +28,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include <qmsgbox.h>
+#include <qmessagebox.h>
 #include <qtimer.h>
 #include <qaccel.h>
 #include <qfile.h>
@@ -40,7 +40,7 @@
 #include <kcmdlineargs.h>
 #include <kio/netaccess.h>
 #include <kmenubar.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 #include "kmahjongg.moc"
 #include "version.h"
@@ -49,6 +49,8 @@
 #include "Progress.h"
 
 #include <kaboutdata.h>
+#include <kpopupmenu.h>
+
 
 static const char *description = I18N_NOOP("KDE Game");
 
@@ -65,8 +67,8 @@ static const char *description = I18N_NOOP("KDE Game");
 // tiles symbol names:
 #define TILE_OFFSET      2
 
-#define TILE_CHARACTER   (0 + TILE_OFFSET)
-#define TILE_BAMBOO      (9 + TILE_OFFSET)
+#define TILE_CHARACTER  ( 0 + TILE_OFFSET)
+#define TILE_BAMBOO      ( 9 + TILE_OFFSET)
 #define TILE_ROD         (18 + TILE_OFFSET)
 #define TILE_SEASON      (27 + TILE_OFFSET)
 #define TILE_WIND        (31 + TILE_OFFSET)
@@ -106,6 +108,7 @@ static const char *description = I18N_NOOP("KDE Game");
 #define EXT_THEME		"*.theme"
 
 int debug_flag = 0;
+
 int is_paused = 0;
 
 Progress *splash=NULL;
@@ -116,6 +119,7 @@ void progress(const QString& foo) {
 	}
 }
 
+
 // ---------------------------------------------------------
 int main( int argc, char** argv )
 {
@@ -127,14 +131,14 @@ int main( int argc, char** argv )
 
     KApplication a;
 
-//splash = new Progress();
-//splash->show();
+ //    splash = new Progress();
+ //    splash->show();
 
      //p.repaint(0,0,-1,-1);
 
     KMahjonggWidget *w = new KMahjonggWidget();
 
-//splash->hide();
+ //   splash->hide();
     w->show();
 
     return( a.exec() );
@@ -245,6 +249,11 @@ KMahjonggWidget::~KMahjonggWidget()
 {
     delete pStatusBar;
     delete pMenuBar;
+    delete prefsDlg;
+    delete previewLoad;
+    delete theHighScores;
+    delete gameNum;
+    delete bw;
 }
 
 
@@ -256,33 +265,33 @@ void KMahjonggWidget::setupToolBar()
 
 	// new game
 	toolBar->insertButton(BarIcon("filenew"),
-		ID_FILE_NEW, TRUE, i18n("New game."));
+		ID_FILE_NEW, TRUE, i18n("New Game."));
 	// new numbered game
 	toolBar->insertButton(UserIcon("newnum"),
-		ID_FILE_NEW_NUMERIC, TRUE, i18n("New numbered game."));
+		ID_FILE_NEW_NUMERIC, TRUE, i18n("New Numbered Game."));
 	// open game
 	toolBar->insertButton(BarIcon("fileopen"),
-		ID_FILE_LOAD_GAME, TRUE, i18n("Open game."));
+		ID_FILE_LOAD_GAME, TRUE, i18n("Open Game."));
 	// save game
 	toolBar->insertButton(BarIcon("filesave"),
-		ID_FILE_SAVE_GAME, TRUE, i18n(" Save game."));
+		ID_FILE_SAVE_GAME, TRUE, i18n(" Save Game."));
 	// undo move
 	toolBar->insertButton(BarIcon("undo"),
-		ID_EDIT_UNDO, TRUE, i18n("Undo move."));
+		ID_EDIT_UNDO, TRUE, i18n("Undo Move."));
 	// redo move
 	toolBar->insertButton(BarIcon("redo"),
-		ID_EDIT_REDO, TRUE, i18n("Redo move."));
+		ID_EDIT_REDO, TRUE, i18n("Redo Move."));
 	// pause
 	toolBar->insertButton(BarIcon("player_pause"),
-		ID_GAME_PAUSE, TRUE, i18n("Pause game."));
+		ID_GAME_PAUSE, TRUE, i18n("Pause Game."));
 	// play
 	toolBar->insertButton(BarIcon("1rightarrow"),
-		ID_GAME_CONTINUE, TRUE, i18n("Play game."));
+		ID_GAME_CONTINUE, TRUE, i18n("Play Game."));
 	// Show hint
 
 	toolBar->insertButton(BarIcon("help"),
 		ID_GAME_HELP, TRUE, i18n("Hint."));
-	
+
 
 
 	// add the timer widget
@@ -293,7 +302,7 @@ void KMahjonggWidget::setupToolBar()
 	toolBar->alignItemRight( ID_GAME_TIMER, true );
 	toolBar->setBarPos(KToolBar::Top);
 	toolBar->show();
-	
+
     connect( toolBar,  SIGNAL(clicked(int) ), SLOT( menuCallback(int) ) );
 }
 
@@ -358,8 +367,8 @@ void KMahjonggWidget::setupMenuBar()
 
   // set up the file menu
   KPopupMenu *file = new KPopupMenu;
-  file->insertItem(SmallIcon("filenew"), i18n("New game"), ID_FILE_NEW);
-  file->insertItem(i18n("New numbered game..."), ID_FILE_NEW_NUMERIC);
+  file->insertItem(SmallIcon("filenew"), i18n("New Game"), ID_FILE_NEW);
+  file->insertItem(i18n("New Numbered Game..."), ID_FILE_NEW_NUMERIC);
   file->insertSeparator();
   file->insertItem(SmallIcon("fileopen"), i18n("&Open Game... "), ID_FILE_LOAD_GAME);
   file->insertItem(i18n("Open The&me..."), ID_FILE_LOAD_THEME);
@@ -376,17 +385,18 @@ void KMahjonggWidget::setupMenuBar()
   edit->insertItem(SmallIcon("undo"), i18n("&Undo"), ID_EDIT_UNDO);
   edit->insertItem(SmallIcon("redo"), i18n("&Redo"), ID_EDIT_REDO);
   edit->insertSeparator();
-  edit->insertItem(i18n("&Board editor..."), ID_EDIT_BOARD_EDIT);
+  edit->insertItem(i18n("&Board Editor..."), ID_EDIT_BOARD_EDIT);
   edit->insertSeparator();
   edit->insertItem(SmallIcon("configure"), i18n("&Preferences..."), ID_EDIT_PREFS);
 
 
   KPopupMenu *game = new KPopupMenu;
-  game->insertItem( i18n("&Help me"),           ID_GAME_HELP );
+  game->insertItem( i18n("&Help Me"),           ID_GAME_HELP );
+  game->setAccel(Key_H, ID_GAME_HELP);
   game->insertItem( SmallIcon("reload"), i18n("Shu&ffle"),           ID_GAME_SHUFFLE );
-  game->insertItem( i18n("&Demo mode"),         ID_GAME_DEMO );
-  game->insertItem( i18n("Show &matching tiles"), ID_GAME_SHOW );
-  game->insertItem( i18n("&Show Hiscores..."), ID_GAME_SHOW_HISCORE );
+  game->insertItem( i18n("&Demo Mode"),         ID_GAME_DEMO );
+  game->insertItem( i18n("Show &Matching Tiles"), ID_GAME_SHOW );
+  game->insertItem( i18n("&Show Highscores..."), ID_GAME_SHOW_HISCORE );
   game->insertSeparator();
   game->insertItem( SmallIcon("player_pause"), i18n("&Pause"), ID_GAME_PAUSE );
   game->insertItem( SmallIcon("1rightarrow"), i18n("&Continue"), ID_GAME_CONTINUE );
@@ -398,9 +408,6 @@ void KMahjonggWidget::setupMenuBar()
            + i18n("\n\nRewritten and extended by ")
            + "David Black"
            + " (david.black@lutris.com)"
-           + i18n("\n\nSolvable game generation by ")
-           + "Michael Haertjens (mhaertjens@modusoperandi.com),"
-		   + "\nbased on algorithm by Michael Meeks in GNOME mahjongg"
 	   + i18n("\n\nTile set contributor and web page maintainer: ")
 	   + "Osvaldo Stark (starko@dnet.it)"
 	   + i18n("\nsee http://freeweb.dnet.it/kmj/ for tile sets and layouts") );
@@ -758,7 +765,7 @@ void KMahjonggWidget::loadGame(void) {
     QString fname;
 
     // Get the name of the file to load
-    KURL url = KFileDialog::getOpenURL( NULL, "*.kmgame", this, i18n("Load game." ) );
+    KURL url = KFileDialog::getOpenURL( NULL, "*.kmgame", this, i18n("Load Game" ) );
 
     if ( url.isEmpty() )
 	return;
@@ -802,7 +809,7 @@ void KMahjonggWidget::loadGame(void) {
 void KMahjonggWidget::saveGame(void) {
 
     // Get the name of the file to save
-    KURL url = KFileDialog::getSaveURL( NULL, "*.kmgame", this, i18n("Save game." ) );
+    KURL url = KFileDialog::getSaveURL( NULL, "*.kmgame", this, i18n("Save Game" ) );
 
     if ( url.isEmpty() )
 	return;
@@ -1504,26 +1511,17 @@ void BoardWidget::calculateNewGame( int gNumber)
     }
 
     if (gNumber == -1) {
-        gameGenerationNum = 0;
+    	gameGenerationNum = 0;
     } else {
-        gameGenerationNum = gNumber;
+	gameGenerationNum = gNumber;
     }
 
     random.setSeed(gameGenerationNum);
 
-	// Translate Game.Map to an array of POSITION data.  We only need to
-	// do this once for each new game.
-	memset(tilePositions, 0, sizeof(tilePositions));
-	generateTilePositions();
-
-	// Now use the tile position data to generate tile dependency data.
-	// We only need to do this once for each new game.
-	generatePositionDepends();
-
-    // Now try to position tiles on the board, 64 tries max.
+    // try max. 64 times
     for( short nr=0; nr<64; nr++ )
     {
-        if( generateStartPosition2())
+        if( generateStartPosition2() )
         {
             drawBoard();
             setStatusText( i18n("Ready. Now it's your turn.") );
@@ -1536,428 +1534,28 @@ void BoardWidget::calculateNewGame( int gNumber)
     setStatusText( i18n("Error generating new game!") );
 }
 
-// ---------------------------------------------------------
-// Generate the position data for the layout from contents of Game.Map.
-void BoardWidget::generateTilePositions() {
 
-	numTiles = 0;
+bool BoardWidget::generateStartPosition2() {
+	int totalTiles=0;
+	POSITION tilesLeft[BoardLayout::maxTiles];
 
+	memset(tilesLeft, 0, sizeof(tilesLeft));
+
+	// zero out all face values	
 	for (int z=0; z< BoardLayout::depth; z++) {
 	    for (int y=0; y<BoardLayout::height; y++) {
-			for (int x=0; x<BoardLayout::width; x++) {
-				Game.Board[z][y][x] = 0;
-				if (Game.Mask[z][y][x] == '1') {
-					tilePositions[numTiles].x = x;
-					tilePositions[numTiles].y = y;		
-					tilePositions[numTiles].e = z;
-					tilePositions[numTiles].f = 254;
-					numTiles++;
-				}
+		for (int x=0; x<BoardLayout::width; x++) {
+			Game.Board[z][y][x]=0;
+			if (Game.Mask[z][y][x] == '1') {
+				tilesLeft[totalTiles].x = x;		
+				tilesLeft[totalTiles].y = y;		
+				tilesLeft[totalTiles].e = z;
+				tilesLeft[totalTiles].f = 254;		
+				totalTiles++;
 			}
+		}
 	    }
 	}
-}
-
-// ---------------------------------------------------------
-// Generate the dependency data for the layout from the position data.
-// Note that the coordinates of each tile in tilePositions are those of
-// the upper left quarter of the tile.
-void BoardWidget::generatePositionDepends() {
-
-	// For each tile,
-	for (int i = 0; i < numTiles; i++) {
-
-		// Get its basic position data
-		int x = tilePositions[i].x;
-		int y = tilePositions[i].y;
-		int z = tilePositions[i].e;
-
-		// LHS dependencies
-		positionDepends[i].lhs_dep[0] = tileAt(x-1, y,   z);
-		positionDepends[i].lhs_dep[1] = tileAt(x-1, y+1, z);
-
-		// Make them unique
-		if (positionDepends[i].lhs_dep[1] == positionDepends[i].lhs_dep[0]) {
-			positionDepends[i].lhs_dep[1] = -1;
-		}
-
-		// RHS dependencies
-		positionDepends[i].rhs_dep[0] = tileAt(x+2, y,   z);
-		positionDepends[i].rhs_dep[1] = tileAt(x+2, y+1, z);
-
-		// Make them unique
-		if (positionDepends[i].rhs_dep[1] == positionDepends[i].rhs_dep[0]) {
-			positionDepends[i].rhs_dep[1] = -1;
-		}
-
-		// Turn dependencies
-		positionDepends[i].turn_dep[0] = tileAt(x,   y,   z+1);
-		positionDepends[i].turn_dep[1] = tileAt(x+1, y,   z+1);
-		positionDepends[i].turn_dep[2] = tileAt(x+1, y+1, z+1);
-		positionDepends[i].turn_dep[3] = tileAt(x,   y+1, z+1);
-
-		// Make them unique
-		for (int j = 0; j < 3; j++) {
-			for (int k = j+1; k < 4; k++) {
-				if (positionDepends[i].turn_dep[j] == 
-					positionDepends[i].turn_dep[k]) {
-					positionDepends[i].turn_dep[k] = -1;
-				}
-			}
-		}
-
-		// Placement dependencies
-		positionDepends[i].place_dep[0] = tileAt(x,   y,   z-1);
-		positionDepends[i].place_dep[1] = tileAt(x+1, y,   z-1);
-		positionDepends[i].place_dep[2] = tileAt(x+1, y+1, z-1);
-		positionDepends[i].place_dep[3] = tileAt(x,   y+1, z-1);
-
-		// Make them unique
-		for (int j = 0; j < 3; j++) {
-			for (int k = j+1; k < 4; k++) {
-				if (positionDepends[i].place_dep[j] == 
-					positionDepends[i].place_dep[k]) {
-					positionDepends[i].place_dep[k] = -1;
-				}
-			}
-		}
-
-		// Filled and free indicators.
-	    positionDepends[i].filled = false;
-	    positionDepends[i].free   = false;
-	}
-}
-
-// ---------------------------------------------------------
-// x, y, z are the coordinates of a *quarter* tile.  This returns the
-// index (in positions) of the tile at those coordinates or -1 if there
-// is no tile at those coordinates.  Note that the coordinates of each
-// tile in positions are those of the upper left quarter of the tile.
-int BoardWidget::tileAt(int x, int y, int z) {
-
-	for (int i = 0; i < numTiles; i++) {
-		if (tilePositions[i].e == z) {
-			if ((tilePositions[i].x == x   && tilePositions[i].y == y) ||
-			    (tilePositions[i].x == x-1 && tilePositions[i].y == y) ||
-			    (tilePositions[i].x == x-1 && tilePositions[i].y == y-1) ||
-			    (tilePositions[i].x == x   && tilePositions[i].y == y-1)) {
-
-				return i;
-			}
-		}
-	}
-	return -1;
-}
-
-// ---------------------------------------------------------
-bool BoardWidget::generateSolvableGame() {
-
-	// Initially we want to mark positions on layer 0 so that we have only
-	// one free position per apparent horizontal line.
-	for (int i = 0; i < numTiles; i++) {
-
-		// Pick a random tile on layer 0
-		int position, cnt = 0;
-		do {
-			position = (int) random.getLong(numTiles);
-			if (cnt++ > (numTiles*numTiles)) {
-				return false; // bail
-			}
-		} while (tilePositions[position].e != 0);
-
-		// If there are no other free positions on the same apparent 
-		// horizontal line, we can mark that position as free.
-		if (onlyFreeInLine(position)) {
-			positionDepends[position].free = true;
-		}
-	}
-
-	// Check to make sure we really got them all.  Very important for
-	// this algorithm.
-	for (int i = 0; i < numTiles; i++) {
-		if (tilePositions[i].e == 0 && onlyFreeInLine(i)) {
-			positionDepends[i].free = true;
-		}
-	}
-
-	// Get ready to place the tiles
-	int lastPosition = -1;
-	int position = -1;
-	int position2 = -1;
-
-	// For each position,
-	for (int i = 0; i < numTiles; i++) {
-
-		// If this is the first tile in a 144 tile set,
-		if ((i % 144) == 0) {
-
-			// Initialise the faces to allocate. For the classic
-			// dragon board there are 144 tiles. So we allocate and
-			// randomise the assignment of 144 tiles. If there are > 144
-			// tiles we will reallocate and re-randomise as we run out.
-			// One advantage of this method is that the pairs to assign are
-			// non-linear. In kmahjongg 0.4, If there were > 144 the same
-			// allocation series was followed. So 154 = 144 + 10 rods.
-			// 184 = 144 + 40 rods (20 pairs) which overwhemed the board
-			// with rods and made deadlock games more likely.
-			randomiseFaces();
-		}
-
-		// If this is the first half of a pair, there is no previous
-		// position for the pair.
-		if ((i & 1) == 0) {
-			lastPosition = -1;
-		}
-
-		// Select a position for the tile, relative to the position of
-		// the last tile placed.
-		if ((position = selectPosition(lastPosition)) < 0) {
-			return false; // bail
-		}
-		if (i < numTiles-1) {
-			if ((position2 = selectPosition(lastPosition)) < 0) {
-				return false; // bail
-			}
-			if (tilePositions[position2].e > tilePositions[position].e) {
-				position = position2;  // higher is better
-			}
-		}
-
-		// Place the tile.
-		placeTile(position, tilePair[i % 144]);
-
-		// Remember the position
-		lastPosition = position;
-	}
-
-    // The game is solvable.
-    return true;
-}
-
-// ---------------------------------------------------------
-// Determines whether it is ok to mark this position as "free" because
-// there are no other positions marked "free" in its apparent horizontal
-// line.
-bool BoardWidget::onlyFreeInLine(int position) {
-
-	int i, i0, w;
-	int lin, rin, out;
-	static int nextLeft[BoardLayout::maxTiles];
-	static int nextRight[BoardLayout::maxTiles];
-
-	/* Check left, starting at position */
-	lin = 0;
-	out = 0;
-	nextLeft[lin++] = position;
-	do {
-		w = nextLeft[out++];
-		if (positionDepends[w].free || positionDepends[w].filled) {
-			return false;
-		}
-		if ((i = positionDepends[w].lhs_dep[0]) != -1) {
-			nextLeft[lin++] = i;
-		}
-		i0 = i;
-		if ((i = positionDepends[w].lhs_dep[1]) != -1 && i0 != i) {
-			nextLeft[lin++] = i;
-		}
-	}
-	while (lin > out) ;
-
-	/* Check right, starting at position */
-	rin = 0;
-	out = 0;
-	nextRight[rin++] = position;
-	do {
-		w = nextRight[out++];
-		if (positionDepends[w].free || positionDepends[w].filled) {
-			return false;
-		}
-		if ((i = positionDepends[w].rhs_dep[0]) != -1) {
-			nextRight[rin++] = i;
-		}
-		i0 = i;
-		if ((i = positionDepends[w].rhs_dep[1]) != -1 && i0 != i) {
-			nextRight[rin++] = i;
-		}
-	}
-	while (rin > out) ;
-
-	// Here, the position can be marked "free"
-	return true;
-}
-
-// ---------------------------------------------------------
-int BoardWidget::selectPosition(int lastPosition) {
-
-	int position, cnt = 0;
-	bool goodPosition = false;
-  
-	// while a good position has not been found,
-	while (!goodPosition) {
-
-		// Select a random, but free, position.
-		do {
-      		position = random.getLong(numTiles);
-			if (cnt++ > (numTiles*numTiles)) {
-				return -1; // bail
-			}
-		} while (!positionDepends[position].free);
-
-		// Found one.
-    	goodPosition = true;
-
-		// If there is a previous position to take into account,
-    	if (lastPosition != -1) {
-
-			// Check the new position against the last one.
-			for (int i = 0; i < 4; i++) {
-				if (positionDepends[position].place_dep[i] == lastPosition) {
-					goodPosition = false;  // not such a good position
-				}
-			}
-			for (int i = 0; i < 2; i++) {
-				if ((positionDepends[position].lhs_dep[i] == lastPosition) ||
-				    (positionDepends[position].rhs_dep[i] == lastPosition)) {
-					goodPosition = false;  // not such a good position
-				}
-			}
-		}
-	}
-
-	return position;
-}
-
-// ---------------------------------------------------------
-void BoardWidget::placeTile(int position, int tile) {
-
-	// Install the tile in the specified position
-	tilePositions[position].f = tile;
-	Game.putTile(tilePositions[position]);
-
-	// Update position dependency data
-	positionDepends[position].filled = true;
-	positionDepends[position].free = false;
-
-	// Now examine the tiles near this to see if this makes them "free".
-    int depend;
-    for (int i = 0; i < 4; i++) {
-		if ((depend = positionDepends[position].turn_dep[i]) != -1) {
-			updateDepend(depend); 
-		}
-	}
-    for (int i = 0; i < 2; i++) {
-		if ((depend = positionDepends[position].lhs_dep[i]) != -1) {
-			updateDepend(depend);
-		}
-		if ((depend = positionDepends[position].rhs_dep[i]) != -1) {
-			updateDepend(depend);
-		}
-	}
-}
-
-// ---------------------------------------------------------
-// Updates the free indicator in the dependency data for a position
-// based on whether the positions on which it depends are filled.
-void BoardWidget::updateDepend(int position) {
-
-	// If the position is valid and not filled
-	if (position >= 0 && !positionDepends[position].filled) {
-
-		// Check placement depends.  If they are not filled, the
-		// position cannot become free.
-		int depend;
-		for (int i = 0; i < 4; i++) {
-			if ((depend = positionDepends[position].place_dep[i]) != -1) {
-				if (!positionDepends[depend].filled) {
-					return ;
-				}
-			}
-		}
-
-		// If position is first free on apparent horizontal, it is
-		// now free to be filled.
-  		if (onlyFreeInLine(position)) {
-      		positionDepends[position].free = true;
-			return;
-		}
-
-		// Assume no LHS positions to fill
-		bool lfilled = false;
-
-  		// If positions to LHS
-		if ((positionDepends[position].lhs_dep[0] != -1) ||
-		    (positionDepends[position].lhs_dep[1] != -1)) {
-
-			// Assume LHS positions filled
-			lfilled = true;      
-
-			for (int i = 0; i < 2; i++) {
-				if ((depend = positionDepends[position].lhs_dep[i]) != -1) {
-					if (!positionDepends[depend].filled) {
-				 		lfilled = false; 
-					}
-				}
-			}
-		}
-  
-		// Assume no RHS positions to fill
-		bool rfilled = false;
-
-  		// If positions to RHS
-		if ((positionDepends[position].rhs_dep[0] != -1) ||
-		    (positionDepends[position].rhs_dep[1] != -1)) {
-
-			// Assume LHS positions filled
-			rfilled = true;      
-
-			for (int i = 0; i < 2; i++) {
-				if ((depend = positionDepends[position].rhs_dep[i]) != -1) {
-					if (!positionDepends[depend].filled) {
-						rfilled = false;
-					}
-				}
-			}
-		}
-
-  		// If positions to left or right are filled, this position 
-		// is now free to be filled.
-  		positionDepends[position].free = (lfilled || rfilled);
-	}
-}
-
-// ---------------------------------------------------------
-bool BoardWidget::generateStartPosition2() {
-
-	// For each tile,
-	for (int i = 0; i < numTiles; i++) {
-
-		// Get its basic position data
-		int x = tilePositions[i].x;
-		int y = tilePositions[i].y;
-		int z = tilePositions[i].e;
-
-		// Clear Game.Board at that position
-		Game.Board[z][y][x] = 0;
-
-		// Clear tile placed/free indicator(s).
-		positionDepends[i].filled = false;
-		positionDepends[i].free   = false;
-
-		// Set tile face blank
-		tilePositions[i].f = 254;
-	}
-
-	// If solvable games should be generated,
-	if (preferences.generateSolvable()) {
-
-		if (generateSolvableGame()) {
-    		Game.TileNum = Game.MaxTileNum;
-			return true;	
-		} else {
-			return false;
-		}
-	}
 
 	// Initialise the faces to allocate. For the classic
 	// dragon board there are 144 tiles. So we allocate and
@@ -1969,13 +1567,17 @@ bool BoardWidget::generateStartPosition2() {
 	// 184 = 144 + 40 rods (20 pairs) which overwhemed the board
 	// with rods and made deadlock games more likely.
 
-	int remaining = numTiles;
+
+	int remaining = totalTiles;
 	randomiseFaces();
 
-	for (int tile=0; tile <numTiles; tile+=2) {
+	for (int tile=0; tile <totalTiles; tile+=2) {
 		int p1;
 		int p2;
 
+
+
+
 		if (remaining > 2) {
 			p2 = p1 = random.getLong(remaining-2);
 			int bail = 0;	
@@ -1987,8 +1589,8 @@ bool BoardWidget::generateStartPosition2() {
 						break;
 					}
 				}
-				if ((tilePositions[p1].y == tilePositions[p2].y) &&
-				    (tilePositions[p1].e == tilePositions[p2].e)) {
+				if ((tilesLeft[p1].y == tilesLeft[p2].y) &&
+				    (tilesLeft[p1].e == tilesLeft[p2].e)) {
 					// skip if on same y line
 					bail++;
 					p2=p1;
@@ -2000,12 +1602,13 @@ bool BoardWidget::generateStartPosition2() {
 			p2 = 1;
 		}
 		POSITION a, b;
-		a = tilePositions[p1];
-		b = tilePositions[p2];
-		tilePositions[p1] = tilePositions[remaining - 1];
-		tilePositions[p2] = tilePositions[remaining - 2];
+		a = tilesLeft[p1];
+		b = tilesLeft[p2];
+		tilesLeft[p1] = tilesLeft[remaining - 1];
+		tilesLeft[p2] = tilesLeft[remaining - 2];
 		remaining -= 2;	
 
+
 		getFaces(a, b);
 		Game.putTile(a);
 		Game.putTile(b);
@@ -2077,6 +1680,18 @@ void BoardWidget::randomiseFaces(void) {
 
 	tilesAllocated = numAlloced;
 	tilesUsed = 0;
+
+/*
+	printf("Allocated %d tiles\n",numAlloced);
+	for (int t=0; t<numAlloced; t++) {
+		printf("%2.2X ", tilePair[t]);
+		if ((t % 20) == 19)
+			printf("\n");
+	}
+
+	printf("\n");
+*/
+
 }
 
 
