@@ -6,6 +6,7 @@
 #include <qbitmap.h>
 #include <qlayout.h>
 #include <qstyle.h>
+#include <qdrawutil.h>
 #include <qtimer.h>
 
 #include <klocale.h>
@@ -562,23 +563,20 @@ void Field::drawBox(QPainter &p, uint i, uint j, bool pressed,
 	int x = iToX(i);
 	int y = jToY(j);
 
-	p.translate(x, y);
+    qDrawShadePanel(&p, x, y, button.width(), button.height(),
+                    colorGroup(),  pressed, 2,
+                    &colorGroup().brush(QColorGroup::Background));
 
-	QStyle::SFlags flags = QStyle::Style_Enabled;
-	if (pressed) flags |= QStyle::Style_Down;
-	else flags |= QStyle::Style_Raised;
-	if ( cursor && i==ic && j==jc ) flags |= QStyle::Style_HasFocus;
+    bool hasFocus = ( cursor && i==ic && j==jc );
+    if (hasFocus) {
+        p.translate(x, y);
+        QRect fbr = style().subRect(QStyle::SR_PushButtonFocusRect, &button);
+        style().drawPrimitive(QStyle::PE_FocusRect, &p, fbr,
+                              colorGroup(), QStyle::Style_Enabled);
+        p.resetXForm();
+    }
 
-	style().drawControl(QStyle::CE_PushButton, &p, &button, button.rect(),
-                        colorGroup(), flags);
-	style().drawControl(QStyle::CE_PushButtonLabel, &p, &button,
-                      style().subRect(QStyle::SR_PushButtonFocusRect, &button),
-                        colorGroup(), flags);
-
-	// we need to draw directly because the pushbutton control clips too much
-	// text and pixmap ...
-	p.resetXForm();
-	QRect r(x, y, cp.size, cp.size);
+	QRect r(QPoint(x, y), button.size());
 	style().drawItem(&p, r, AlignCenter, colorGroup(), true, pixmap,
                          text, -1, &textColor);
 }
