@@ -13,23 +13,21 @@
 #include "dialogs.h"
 
 
-/* mines field widget */
-class Field : public QFrame
+//-----------------------------------------------------------------------------
+class Field : public QFrame, public KMines
 {
  Q_OBJECT
-
  public:
-    Field(QWidget *parent, const char *name=0);
-	virtual ~Field();
+	Field(QWidget *parent);
 
 	QSize sizeHint() const;
 	QSizePolicy sizePolicy() const;
 
-	void restart(bool repaint = true);
-    bool isPaused() const { return state==Paused; }
+	void restart();
+	bool isPaused() const { return state==Paused; }
 	void pause();
 	void stop() { state = Stopped; }
-	void showMines();
+    void showMines();
 
 	void up();
 	void down();
@@ -40,9 +38,11 @@ class Field : public QFrame
 	void umark();
 	void keyboardAutoReveal();
 
-	void setLevel(const LevelData &);
-	const LevelData &level() const { return lev; }
+	void setLevel(const Level &);
+	const Level &level() const { return _level; }
 	void readSettings();
+	void setCaseSize(uint s);
+	uint caseSize() const { return cp.size; }
 
  public slots:
 	void resume();
@@ -51,10 +51,11 @@ class Field : public QFrame
 	void changeCase(CaseState, int);
 	void updateStatus(bool);
 	void setMood(Smiley::Mood);
-	void endGame();
+	void gameLost();
 	void startTimer();
-	void freezeTimer();
+	void stopTimer();
 	void gameStateChanged(GameState);
+    void incActions();
 
  protected:
 	void paintEvent(QPaintEvent *);
@@ -63,16 +64,15 @@ class Field : public QFrame
 	void mouseMoveEvent(QMouseEvent *);
 
  private slots:
-    void keyboardAutoRevealSlot();
+	void keyboardAutoRevealSlot();
 
  private:
-	QArray<Case>    _pfield;
-	LevelData       lev;
-	KRandomSequence random;
+	QMemArray<Case>    _pfield;
+	Level              _level;
+	KRandomSequence    _random;
 
 	GameState state;
-	bool      first_click;
-	bool      u_mark, cursor;
+	bool u_mark, cursor, firstReveal;
 
 	uint  ic, jc;              // current pos
 	MouseAction mb[3];         // mouse bindings
@@ -80,7 +80,7 @@ class Field : public QFrame
 
 	CaseProperties cp;
 	QPixmap        pm_flag, pm_mine, pm_exploded, pm_error;
-	QPushButton   *pb, *dummy;
+	QPushButton    button;
 
 	uint computeNeighbours(uint, uint) const;
 	void uncover(uint, uint);
@@ -93,7 +93,6 @@ class Field : public QFrame
 	bool placeCursor(int, int);
 	void flagPixmap(QPixmap &, bool mask) const;
 	void autoReveal();
-	void _endGame();
 	bool revealActions(bool press);
 
 	const Case &pfield(uint i, uint j) const;
@@ -103,11 +102,10 @@ class Field : public QFrame
 	int iToX(uint i) const;
 	int jToY(uint j) const;
 
-	void drawCase(uint, uint);
-	void drawBox(uint, uint, bool, const QString &text = QString::null,
-				 const QColor *color = 0, const QPixmap *pixmap = 0);
-	void drawBox(uint i, uint j, bool pressed, const QPixmap *pixmap)
-		{ drawBox(i, j, pressed, QString::null, 0, pixmap); }
+	void drawCase(QPainter &, uint, uint);
+	void drawBox(QPainter &, uint, uint, bool, const QPixmap * = 0,
+                 const QString &text = QString::null,
+                 const QColor &textColor = black);
 	void eraseField();
 
 	void setUMark(bool um) { u_mark = um; }
