@@ -2,6 +2,7 @@
 #include <qlayout.h>
 #include <qcolor.h>
 #include <qpalette.h>
+#include <qcolor.h>
 #include <kapplication.h>
 #include <klocale.h>
 
@@ -15,30 +16,30 @@ PlanetInfo::PlanetInfo( QWidget *parent, QPalette palette )
     setPalette( palette );
 
     name = new QLabel( this );
-    name->setPalette( palette );
-
+    name->setMinimumWidth( 100 );
     owner = new QLabel( this );
-    owner->setPalette( palette );
-
+    owner->setMinimumWidth( 100 );
     ships = new QLabel( this );
-    ships->setPalette( palette );
-
+    ships->setMinimumWidth( 100 );
     production = new QLabel( this );
-    production->setPalette( palette );
-
+    production->setMinimumWidth( 100 );
     kill_percent = new QLabel( this );
-    kill_percent->setPalette( palette );
+    kill_percent->setMinimumWidth( 100 );
 
     clearDisplay();
 
-    QVBoxLayout *layout = new QVBoxLayout( this );
-    layout->addWidget( name );
-    layout->addWidget( owner );
-    layout->addWidget( ships );
-    layout->addWidget( production );
-    layout->addWidget( kill_percent );
+    QVBoxLayout *layout1 = new QVBoxLayout( this );
+    
+    layout1->addWidget( name );
+    layout1->addWidget( owner );
+    layout1->addWidget( ships );
+    layout1->addWidget( production );
+    layout1->addWidget( kill_percent );
+    layout1->addStretch(1);
 
-    setMaximumSize( 32767, 80 );
+    setMouseTracking( true );
+
+    setMaximumSize( sizeHint() );
 }
 
 PlanetInfo::~PlanetInfo()
@@ -46,6 +47,19 @@ PlanetInfo::~PlanetInfo()
     emptyPlanetInfoList();
 }
 
+QSize PlanetInfo::sizeHint() const
+{
+    int height;
+    
+    height = name->sizeHint().height() +
+    		owner->sizeHint().height() +
+		ships->sizeHint().height() +
+		production->sizeHint().height()+
+		kill_percent->sizeHint().height();
+		
+    return QSize( 100, height );
+}
+
 void PlanetInfo::setPlanetList( PlanetList &newPlanets )
 {
     emptyPlanetInfoList();
@@ -145,3 +159,4 @@ void PlanetInfo::showPlanet( Planet *planet )
         }
     }
 }
+
