@@ -21,11 +21,8 @@
 //
 ****************************************/
 
-#include <qcombobox.h>
-#include <krandomsequence.h>
 #include "computation.h"
 #include <klocale.h>
-#include <kmainwindow.h>
 #include <pile.h>
 #include <deck.h>
 #include <assert.h>
@@ -97,6 +94,9 @@ bool Computation::checkAdd( int index, const Pile* c1, const CardList& cl) const
 
     assert(c1->index() >= 5 && c1->index() <= 8);
 
+    if ( c1->cardsLeft() == 13 )
+      return false;
+
     int offset = c1->index() - 4;
 
     if (c1->isEmpty()) {
