@@ -1,17 +1,15 @@
 #include "dealer.h"
-#include <qobjcoll.h>
 #include <kstaticdeleter.h>
+#include <qpainter.h>
 #include <kdebug.h>
 #include <assert.h>
 #include "pile.h"
 #include "kmainwindow.h"
-#include <qtl.h>
-#include <kapp.h>
-#include <kmessagebox.h>
+#include <kapplication.h>
+#include <kpixmapeffect.h>
 #include <qtimer.h>
 #include <kaction.h>
 #include <klocale.h>
-#include <kstddirs.h>
 #include <cardmaps.h>
 #include <speeds.h>
 
@@ -58,9 +56,9 @@ void Dealer::setBackgroundPixmap(const QPixmap &background, const QColor &midcol
 
 void Dealer::setupActions() {
 
-    QList<KAction> actionlist;
+    QPtrList<KAction> actionlist;
 
-    kdDebug() << "setupActions " << actions() << endl;
+    kdDebug(11111) << "setupActions " << actions() << endl;
 
     if (actions() & Dealer::Hint) {
 
@@ -125,7 +123,7 @@ void Dealer::getHints()
         Pile *store = *it;
         if (store->isEmpty())
             continue;
-//        kdDebug() << "trying " << store->top()->name() << endl;
+//        kdDebug(11111) << "trying " << store->top()->name() << endl;
 
         CardList cards = store->cards();
         while (cards.count() && !cards.first()->realFace()) cards.remove(cards.begin());
@@ -134,7 +132,7 @@ void Dealer::getHints()
         while (iti != cards.end())
         {
             if (store->legalRemove(*iti)) {
-//                kdDebug() << "could remove " << (*iti)->name() << endl;
+//                kdDebug(11111) << "could remove " << (*iti)->name() << endl;
                 for (PileList::Iterator pit = piles.begin(); pit != piles.end(); ++pit)
                 {
                     Pile *dest = *pit;
@@ -221,7 +219,7 @@ void Dealer::contentsMouseMoveEvent(QMouseEvent* e)
                 if (p->isEmpty() && !sources.contains(p))
                     sources.append(p);
             } else {
-                kdDebug() << "unknown object " << *it << " " << (*it)->rtti() << endl;
+                kdDebug(11111) << "unknown object " << *it << " " << (*it)->rtti() << endl;
             }
         }
     }
@@ -271,7 +269,7 @@ void Dealer::contentsMousePressEvent(QMouseEvent* e)
 
     QCanvasItemList list = canvas()->collisions(e->pos());
 
-    kdDebug() << "mouse pressed " << list.count() << " " << canvas()->allItems().count() << endl;
+    kdDebug(11111) << "mouse pressed " << list.count() << " " << canvas()->allItems().count() << endl;
     moved = false;
 
     if (!list.count())
@@ -390,7 +388,7 @@ void Dealer::contentsMouseReleaseEvent( QMouseEvent *e)
                     sources.append(t);
                 }
             } else {
-                kdDebug() << "unknown object " << *it << " " << (*it)->rtti() << endl;
+                kdDebug(11111) << "unknown object " << *it << " " << (*it)->rtti() << endl;
             }
         }
     }
@@ -497,7 +495,7 @@ void Dealer::resizeEvent(QResizeEvent *e)
 }
 
 void Dealer::cardClicked(Card *c) {
-    kdDebug() << "card clicked " << c->name() << endl;
+    kdDebug(11111) << "card clicked " << c->name() << endl;
     c->source()->cardClicked(c);
 }
 
@@ -509,7 +507,7 @@ void Dealer::cardDblClicked(Card *c)
 {
     c->source()->cardDblClicked(c);
 
-    kdDebug() << "card dbl clicked " << c->name() << endl;
+    kdDebug(11111) << "card dbl clicked " << c->name() << endl;
 
     if (c->animated())
         return;
@@ -530,11 +528,11 @@ void Dealer::startNew()
     minsize = QSize(0,0);
     _won = false;
     _waiting = 0;
-    kdDebug() << "startNew stopDemo\n";
+    kdDebug(11111) << "startNew stopDemo\n";
     stopDemo();
-    kdDebug() << "startNew unmarkAll\n";
+    kdDebug(11111) << "startNew unmarkAll\n";
     unmarkAll();
-    kdDebug() << "startNew setAnimated(false)\n";
+    kdDebug(11111) << "startNew setAnimated(false)\n";
     QCanvasItemList list = canvas()->allItems();
     for (QCanvasItemList::Iterator it = list.begin(); it != list.end(); ++it) {
         if ((*it)->rtti() == Card::RTTI)
@@ -546,16 +544,18 @@ void Dealer::startNew()
 
     undoList.clear();
     emit undoPossible(false);
-    kdDebug() << "startNew restart\n";
+    kdDebug(11111) << "startNew restart\n";
     restart();
+    takeState();
     Card *towait = 0;
     for (QCanvasItemList::Iterator it = list.begin(); it != list.end(); ++it) {
         if ((*it)->rtti() == Card::RTTI) {
             towait = static_cast<Card*>(*it);
-            break;
+            if (towait->animated())
+                break;
         }
     }
-    kdDebug() << "startNew takeState\n";
+    kdDebug(11111) << "startNew takeState\n";
     if (!towait)
         takeState();
     else
@@ -571,17 +571,17 @@ void Dealer::slotTakeState(Card *c) {
 
 void Dealer::enlargeCanvas(QCanvasRectangle *c)
 {
-    if (!c->visible() || c->animated())
+    if (!c->isVisible() || c->animated())
         return;
 
     bool changed = false;
 
     if (c->x() + c->width() + 10 > minsize.width()) {
-        minsize.setWidth(c->x() + c->width() + 10);
+        minsize.setWidth(int(c->x()) + c->width() + 10);
         changed = true;
     }
     if (c->y() + c->height() + 10 > minsize.height()) {
-        minsize.setHeight(c->y() + c->height() + 10);
+        minsize.setHeight(int(c->y()) + c->height() + 10);
         changed = true;
     }
     if (changed)
@@ -674,7 +674,7 @@ State *Dealer::getState()
            s.it = c;
            s.source = c->source();
            if (!s.source) {
-               kdDebug() << c->name() << " has no parent\n";
+               kdDebug(11111) << c->name() << " has no parent\n";
                assert(false);
            }
            s.i = c->source()->indexOf(c);
@@ -718,11 +718,11 @@ void Dealer::setState(State *st)
         CardState s = *it;
         bool target = c->takenDown(); // abused
         s.source->add(c, s.i);
-        c->setVisible(s.source->visible());
+        c->setVisible(s.source->isVisible());
         c->setAnimated(false);
         c->setX(s.x);
         c->setY(s.y);
-        c->setZ(s.z);
+        c->setZ(int(s.z));
         c->setTakenDown(s.tookdown || (target && !s.source->target()));
         c->turn(s.faceup);
     }
@@ -737,7 +737,7 @@ void Dealer::setState(State *st)
 
 void Dealer::takeState()
 {
-    kdDebug() << "takeState\n";
+    kdDebug(11111) << "takeState\n";
 
     State *n = getState();
 
@@ -755,7 +755,11 @@ void Dealer::takeState()
     }
 
     if (n) {
-        if (isGameWon()) {
+		if (isGameLost()){
+			emit gameLost();	
+	    	return;
+			}
+        else if (isGameWon()) {
             won();
             return;
         } else if (!demoActive() && !waiting()) {
@@ -768,9 +772,9 @@ void Dealer::takeState()
 void Dealer::saveGame(QDataStream &s) {
     s << 0; // file format
     s << _id; // dealer number
-    s << Q_UINT64(gameNumber());
+    s << Q_ULONG (gameNumber());
     s << undoList.count();
-    QListIterator<State> it(undoList);
+    QPtrListIterator<State> it(undoList);
 
     for (; it.current(); ++it)
     {
@@ -783,7 +787,7 @@ void Dealer::saveGame(QDataStream &s) {
 void Dealer::openGame(QDataStream &s)
 {
     unmarkAll();
-    Q_UINT64 gn;
+    Q_ULONG gn;
     s >> gn;
     setGameNumber(gn);
     uint count;
@@ -858,7 +862,7 @@ void Dealer::setWaiting(bool w)
     else
         _waiting--;
     emit undoPossible(!waiting());
-    kdDebug() << "setWaiting " << w << " " << _waiting << endl;
+    kdDebug(11111) << "setWaiting " << w << " " << _waiting << endl;
 }
 
 bool Dealer::startAutoDrop()
@@ -866,7 +870,7 @@ bool Dealer::startAutoDrop()
     if (movingCards.count())
         return false;
 
-    kdDebug() << "startAutoDrop\n";
+    kdDebug(11111) << "startAutoDrop\n";
 
     unmarkAll();
     clearHints();
@@ -884,8 +888,8 @@ bool Dealer::startAutoDrop()
             int y = int(t->y());
             t->source()->moveCards(cards, mh->pile());
             t->move(x, y);
-            kdDebug() << "autodrop " << t->name() << endl;
-            t->animatedMove(t->source()->x(), t->source()->y(), t->z(), STEPS_AUTODROP);
+            kdDebug(11111) << "autodrop " << t->name() << endl;
+            t->animatedMove(int(t->source()->x()), int(t->source()->y()), int(t->z()), STEPS_AUTODROP);
             connect(t, SIGNAL(stoped(Card*)), SLOT(waitForAutoDrop(Card*)));
             return true;
         }
@@ -895,7 +899,7 @@ bool Dealer::startAutoDrop()
 }
 
 void Dealer::waitForAutoDrop(Card * c) {
-    kdDebug() << "waitForAutoDrop " << c->name() << endl;
+    kdDebug(11111) << "waitForAutoDrop " << c->name() << endl;
     setWaiting(false);
     c->disconnect();
     takeState();
@@ -923,7 +927,7 @@ void Dealer::removePile(Pile *p)
 
 void Dealer::stopDemo()
 {
-    kdDebug() << "stopDemo " << waiting() << " " << stop_demo_next << endl;
+    kdDebug(11111) << "stopDemo " << waiting() << " " << stop_demo_next << endl;
     if (waiting()) {
         stop_demo_next = true;
         return;
@@ -1033,7 +1037,7 @@ void Dealer::demo() {
 
         for (CardList::Iterator it = empty.begin(); it != empty.end(); ++it) {
             Card *t = *it;
-            ASSERT(!t->animated());
+            Q_ASSERT(!t->animated());
             t->setAnimated(false);
             t->turn(true);
             oldcoords[i++] = int(t->realX());
@@ -1054,7 +1058,7 @@ void Dealer::demo() {
             int x2 = int(t->realX());
             int y2 = int(t->realY());
             t->move(x1, y1);
-            t->animatedMove(x2, y2, t->z(), STEPS_DEMO);
+            t->animatedMove(x2, y2, int(t->z()), STEPS_DEMO);
         }
 
         delete [] oldcoords;
@@ -1108,6 +1112,12 @@ bool Dealer::isGameWon() const
     return true;
 }
 
+bool Dealer::isGameLost() const
+{
+//PCG: assume not, let the individual games decide.
+	return false;
+}
+
 bool Dealer::checkRemove( int, const Pile *, const Card *) const {
     return true;
 }
@@ -1119,36 +1129,39 @@ bool Dealer::checkAdd( int, const Pile *, const CardList&) const {
 void Dealer::drawPile(KPixmap &pixmap, Pile *pile, bool selected)
 {
     QPixmap bg = myCanvas.backgroundPixmap();
-    QRect bounding(pile->x(), pile->y(), cardMap::CARDX, cardMap::CARDY);
+    QRect bounding(int(pile->x()), int(pile->y()), cardMap::CARDX, cardMap::CARDY);
 
     pixmap.resize(bounding.width(), bounding.height());
     pixmap.fill(Qt::white);
 
-    for (int x=bounding.x()/bg.width();
-         x<(bounding.x()+bounding.width()+bg.width()-1)/bg.width(); x++)
-    {
-        for (int y=bounding.y()/bg.height();
-             y<(bounding.y()+bounding.height()+bg.height()-1)/bg.height(); y++)
+    if (!bg.isNull()) {
+        for (int x=bounding.x()/bg.width();
+             x<(bounding.x()+bounding.width()+bg.width()-1)/bg.width(); x++)
         {
-            int sx = 0;
-            int sy = 0;
-            int dx = x*bg.width()-bounding.x();
-            int dy = y*bg.height()-bounding.y();
-            int w = bg.width();
-            int h = bg.height();
-            if (dx < 0) {
-                sx = -dx;
+            for (int y=bounding.y()/bg.height();
+                 y<(bounding.y()+bounding.height()+bg.height()-1)/bg.height(); y++)
+            {
+                int sx = 0;
+                int sy = 0;
+                int dx = x*bg.width()-bounding.x();
+                int dy = y*bg.height()-bounding.y();
+                int w = bg.width();
+                int h = bg.height();
+                if (dx < 0) {
+                    sx = -dx;
                 dx = 0;
+                }
+                if (dy < 0) {
+                    sy = -dy;
+                    dy = 0;
+                }
+                bitBlt(&pixmap, dx, dy, &bg,
+                       sx, sy, w, h, Qt::CopyROP, true);
             }
-            if (dy < 0) {
-                sy = -dy;
-                dy = 0;
-            }
-            bitBlt(&pixmap, dx, dy, &bg,
-                   sx, sy, w, h, Qt::CopyROP, true);
         }
     }
 
+
     float s = -0.1;
     float n = -0.3;
 
@@ -1161,13 +1174,6 @@ void Dealer::drawPile(KPixmap &pixmap, Pile *pile, bool selected)
     }
 
     KPixmapEffect::intensity(pixmap, selected ? s : n);
-
-    QPainter painter(&pixmap);
-
-    QColorGroup colgrp( Qt::black, Qt::white, midColor().light(),
-                        midColor().dark(), midColor(), Qt::black,
-                        Qt::white );
-    kapp->style().drawPanel( &painter, 0, 0, cardMap::CARDX, cardMap::CARDY, colgrp, true );
 }
 
 int Dealer::freeCells() const
@@ -1181,7 +1187,7 @@ int Dealer::freeCells() const
 
 void Dealer::setAnchorName(const QString &name)
 {
-    kdDebug() << "setAnchorname " << name << endl;
+    kdDebug(11111) << "setAnchorname " << name << endl;
     ac = name;
 }
 
