@@ -28,6 +28,13 @@ enum FCS_SEQUENCES_ARE_BUILT_BY_T
     FCS_SEQ_BUILT_BY_RANK
 };
 
+enum FCS_TALON_T
+{
+    FCS_TALON_NONE,
+    FCS_TALON_GYPSY,
+    FCS_TALON_KLONDIKE
+};
+
 enum freecell_solver_state_solving_return_codes
 {
     FCS_STATE_WAS_SOLVED,
@@ -40,13 +47,26 @@ enum freecell_solver_state_solving_return_codes
     FCS_STATE_ORIGINAL_STATE_IS_NOT_SOLVEABLE,
     FCS_STATE_INVALID_STATE,
     FCS_STATE_NOT_BEGAN_YET,
-    FCS_STATE_DOES_NOT_EXIST
+    FCS_STATE_DOES_NOT_EXIST,
+    FCS_STATE_OPTIMIZED
 };
 
+enum fcs_presets_return_codes
+{
+    FCS_PRESET_CODE_OK,
+    FCS_PRESET_CODE_NOT_FOUND,
+    FCS_PRESET_CODE_FREECELLS_EXCEED_MAX,
+    FCS_PRESET_CODE_STACKS_EXCEED_MAX,
+    FCS_PRESET_CODE_DECKS_EXCEED_MAX
+};
+
+
+#define FCS_METHOD_NONE -1
 #define FCS_METHOD_HARD_DFS 0
 #define FCS_METHOD_SOFT_DFS 1
 #define FCS_METHOD_BFS 2
 #define FCS_METHOD_A_STAR 3
+#define FCS_METHOD_OPTIMIZE 4
 
 
 #ifdef __cplusplus
