@@ -1,11 +1,7 @@
 #include "gypsy.h"
 #include <klocale.h>
-#include <kdebug.h>
 #include "pile.h"
 #include "deck.h"
-#include <kmainwindow.h>
-#include <kaction.h>
-#include <qlist.h>
 
 Gypsy::Gypsy( KMainWindow* parent, const char *name )
     : Dealer( parent, name )
@@ -59,7 +55,7 @@ Card *Gypsy::demoNewCards()
 static class LocalDealerInfo7 : public DealerInfo
 {
 public:
-    LocalDealerInfo7() : DealerInfo(I18N_NOOP("G&ypsy"), 7) {}
+    LocalDealerInfo7() : DealerInfo(I18N_NOOP("Gy&psy"), 7) {}
     virtual Dealer *createGame(KMainWindow *parent) { return new Gypsy(parent); }
 } gyfdi;
 
