@@ -18,15 +18,11 @@
 
 ---------------------------------------------------------------------------*/
 
-#include <qdialog.h>
 #include "mod3.h"
 #include <klocale.h>
-#include <kmessagebox.h>
 #include "deck.h"
 #include "pile.h"
 #include <kdebug.h>
-#include <kmainwindow.h>
-#include <kaction.h>
 
 //-------------------------------------------------------------------------//
 
