@@ -28,11 +28,11 @@
 
 // KDE includes
 #include <kmessagebox.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <kmenubar.h>
 #include <kstdaccel.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 #include <kconfig.h>
 #include <kaccel.h>
@@ -64,7 +64,7 @@ kpok::kpok(QWidget *parent, const char *name) : QWidget(parent, name)
         version = kapp->caption() + " " + KPOKER_VERSION;
 	setCaption( version );
 
-	options = 0;
+	mOptions = 0;
 	newGameDlg = 0;
 
 	initSomeStuff();
@@ -76,20 +76,20 @@ kpok::kpok(QWidget *parent, const char *name) : QWidget(parent, name)
 
 kpok::~kpok()
 {
- if (options != 0) {
+ if (mOptions != 0) {
 	if (player.count() + removedPlayers.count() > 1) {
-		minBet = options->getMinBet();
-		maxBet = options->getMaxBet();
+		minBet = mOptions->getMinBet();
+		maxBet = mOptions->getMaxBet();
 	}
-	drawDelay = options->getDrawDelay();
-	cashPerRound = options->getCashPerRound();
+	drawDelay = mOptions->getDrawDelay();
+//	cashPerRound = mOptions->getCashPerRound(); // NOT(!) configurable
  }
 
  KConfig* conf = kapp->config();
  conf->setGroup("General");
  conf->writeEntry("MaxBet", maxBet);
  conf->writeEntry("MinBet", minBet);
- conf->writeEntry("CashPerRound", cashPerRound);
+// conf->writeEntry("CashPerRound", cashPerRound);
  conf->writeEntry("DrawDelay", drawDelay);
 
  delete kacc;
@@ -98,8 +98,8 @@ kpok::~kpok()
  delete playerBox;// necessary?
  delete[] allPlayers;
  delete[] done;
- if (options != 0)
-	delete options;
+ if (mOptions != 0)
+	delete mOptions;
  if (newGameDlg != 0)
 	delete newGameDlg;
  player.clear();
@@ -363,7 +363,8 @@ void kpok::initPoker(int players, Player* ownAllPlayers)
  kapp->config()->setGroup("General");
  minBet = kapp->config()->readNumEntry("MinBet", MIN_BET);
  maxBet = kapp->config()->readNumEntry("MaxBet", MAX_BET);
- cashPerRound = kapp->config()->readNumEntry("CashPerRound", CASH_PER_ROUND);
+// cashPerRound = kapp->config()->readNumEntry("CashPerRound", CASH_PER_ROUND); // NOT(!) configurable
+ cashPerRound = CASH_PER_ROUND;
  drawDelay = kapp->config()->readNumEntry("DrawDelay", DRAWDELAY);
 
  blinkingBox = 0;
@@ -371,7 +372,7 @@ void kpok::initPoker(int players, Player* ownAllPlayers)
  currentMustBet = minBet;
 
 // init the players first
-// we use a QList to access the players
+// we use a QPtrList to access the players
  player.clear();
  removedPlayers.clear();
  if (ownAllPlayers == 0) {
@@ -1027,14 +1028,14 @@ void kpok::toggleAdjust() { setAdjust(!adjust); }
 
 void kpok::slotPreferences()
 {
- options = new OptionsDlg(this, 0, player.count() + removedPlayers.count());
+ mOptions = new OptionsDlg(this, 0, player.count() + removedPlayers.count());
  if (player.count() + removedPlayers.count() > 1)
-	options->init(drawDelay, maxBet, minBet);
+	mOptions->init(drawDelay, maxBet, minBet);
  else
-	options->init(drawDelay, cashPerRound);
- if (!options->exec()) {
-	delete options;
-	options = 0;
+	mOptions->init(drawDelay, cashPerRound);
+ if (!mOptions->exec()) {
+	delete mOptions;
+	mOptions = 0;
  }
 }
 
@@ -1069,18 +1070,18 @@ void kpok::setSound(bool s)
 
 void kpok::readOptions()
 {
- if (options != 0) {
+ if (mOptions != 0) {
 	if (player.count() + removedPlayers.count() > 1) {
-		minBet = options->getMinBet();
-		maxBet = options->getMaxBet();
+		minBet = mOptions->getMinBet();
+		maxBet = mOptions->getMaxBet();
 		for (int unsigned i = 0; i < player.count(); i++)
 			player.at(i)->setBetDefaults(minBet, maxBet); // inform players how much they may bet
 	}
-	drawDelay = options->getDrawDelay();
-	kdDebug() << cashPerRound << endl;
-	cashPerRound = options->getCashPerRound();
-	delete options;
-	options = 0;
+	drawDelay = mOptions->getDrawDelay();
+//	kdDebug() << cashPerRound << endl;
+//	cashPerRound = mOptions->getCashPerRound(); // NOT(!) configurable
+	delete mOptions;
+	mOptions = 0;
  }
 }
 
