@@ -19,7 +19,7 @@
 
 // QT includes
 #include <qwidget.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 // KDE includes
 #include <krandomsequence.h>
@@ -223,10 +223,10 @@ private:
 
 	PlayerBox** playerBox;        //one box per player
 	Player *allPlayers;           //the players
-	QList<Player> player;         //players in the round
-	QList<Player> removedPlayers; //players not in the round
+	QPtrList<Player> player;         //players in the round
+	QPtrList<Player> removedPlayers; //players not in the round
 
-	OptionsDlg* options;
+	OptionsDlg* mOptions;
 	NewGameDlg* newGameDlg;
 	
 	QLabel       *potLabel;
