@@ -18,14 +18,16 @@
 #include <qtooltip.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <qtimer.h>
 
 // KDE includes
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <kaccel.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kcarddialog.h>
+#include <kdebug.h>
 
 // own includes
 #include "betbox.h"
@@ -79,10 +81,21 @@ void kpok::initSomeStuff()
  inputLayout->addWidget(drawButton);
  inputLayout->addStretch(1);
 
- wonLabel = new QLabel(this);
- wonLabel->hide();
+ QFont waveFont;
+ waveFont.setBold(true);
+ waveFont.setPointSize(16);
+ QFontMetrics tmp(waveFont);
+ mWonWidget = new QWidget(this);
+ inputLayout->addWidget(mWonWidget, 2);
+ mWonWidget->setMinimumHeight(50); //FIXME hardcoded value for the wave
+ mWonWidget->setMinimumWidth(tmp.width(i18n("You won %1").arg(KGlobal::locale()->formatMoney(100))) + 20); // workaround for width problem in wave
+ QHBoxLayout* wonLayout = new QHBoxLayout(mWonWidget);
+ wonLayout->setAutoAdd(true);
+
+ wonLabel = new QLabel(mWonWidget);
  wonLabel->setFont(wonFont);
- inputLayout->addWidget(wonLabel);
+ wonLabel->setAlignment(AlignCenter);
+ wonLabel->hide();
  inputLayout->addStretch(1);
 
  potLabel = new QLabel(this);
