@@ -19,6 +19,8 @@
 
 #include <kmainwindow.h>
 
+class QLabel;
+
 class KMenuBar;
 class KToolBar;
 class KStatusBar;
@@ -28,11 +30,6 @@ class PokerWindow : public KMainWindow
 {
 	Q_OBJECT
 private:
-//	KMenuBar        *menu;
-
-	QPopupMenu	*filePopup;
-	QPopupMenu	*optionsPopup;
-	
 	kpok            *_kpok;
 
 	// statusbar elements:
@@ -41,17 +38,26 @@ private:
 protected slots:
         void saveProperties(KConfig*);
         void readProperties(KConfig*);
-	void commandCallback(int id);
 	void setHand(QString newHand, bool lastHand = true);
 	void showClickToHold(bool show);
+	void statusBarMessage(QString);
+	void clearStatusBar();
 	void saveOptions();
+	void toggleMenubar();
+	void toggleStatusbar();
 	
 public:
 	PokerWindow();
 	~PokerWindow();
 
- protected:
+protected:
 	virtual bool queryClose();
+	bool eventFilter(QObject*, QEvent*);
+	void initKAction();
+	void readOptions();
+
+private:
+	bool clickToHoldIsShown;
 };
 
 #endif
