@@ -125,9 +125,8 @@
 #include "Game.h"
 #include "Move.h"
 #include "Score.h"
-#include "qarray.h"
+#include <qmemarray.h>
 #include <sys/times.h>
-#include "misc.h"
 #include <qbitarray.h>
 
 #if defined(__GNUC__)
@@ -167,7 +166,7 @@ public:
   void Push(int x, int y);
 
 private:
-  QArray<SquareStackEntry> m_squarestack;
+  QMemArray<SquareStackEntry> m_squarestack;
   int m_top;
 };
 
