@@ -20,20 +20,21 @@
  */
 
 #include <stdio.h>
-#include <kapp.h>
+
 #include <qaccel.h>
 #include <qwidget.h>
 #include <qpushbutton.h>
 #include <qpixmap.h>
-#include <kiconloader.h>
-#include "StoneWidget.h"
-#include "version.h"
-#include "KSameWidget.moc"
+#include <qvbox.h>
 #include <qpopupmenu.h>
+
+#include <kapplication.h>
+#include <kiconloader.h>
+#include <kdialogbase.h>
+#include <kscoredialog.h>
 #include <kstatusbar.h>
 #include <knuminput.h>
 #include <klocale.h>
-
 #include <knotifyclient.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
@@ -43,35 +44,41 @@
 #include <kaction.h>
 #include <kdebug.h>
 
+#include "KSameWidget.h"
+#include "StoneWidget.h"
+#include "version.h"
+
 static int default_colors=3;
 
+#define Board 	KScoreDialog::Custom1
+
 KSameWidget::KSameWidget() : KMainWindow(0)
 {
         setCaption("");
 	KStdAction::openNew(this, SLOT(m_new()), actionCollection(), "game_new");
-	restart = new KAction(i18n("&Restart this board"), CTRL+Key_R, this,
+	restart = new KAction(i18n("&Restart this Board"), CTRL+Key_R, this,
 						  SLOT(m_restart()), actionCollection(), "game_restart");
        // KStdAction::open(this, SLOT(m_load()), actionCollection(), "game_load");
        // KStdAction::save(this, SLOT(m_save()), actionCollection(), "game_save");
 	new KAction(i18n("S&how Highscore"), CTRL+Key_H, this,
 				SLOT(m_showhs()), actionCollection(), "game_highscores");
 	KStdAction::quit(this, SLOT(m_quit()), actionCollection(), "game_quit");
-	
+
 	undo = KStdAction::undo(this, SLOT(m_undo()),
 							actionCollection(), "edit_undo");
 
 	random = new KToggleAction(i18n("&Random Board"), 0, this,
 							   SLOT(m_tglboard()), actionCollection(),
 							   "random_board");
-	
+
 	status=statusBar();
 	status->insertItem(i18n("Colors: XX"),1,1);
 	status->insertItem(i18n("Board: XXXXXX"),2,1);
 	status->insertItem(i18n("Marked: XXXXXX"),3,1);
 	status->insertItem(i18n("Score: XXXXXX"),4,1);
-	
+
 	stone = new StoneWidget(this,15,10);
-	
+
 	connect( stone, SIGNAL(s_gameover()), this, SLOT(gameover()));
 
 	connect( stone, SIGNAL(s_colors(int)), this, SLOT(setColors(int)));
@@ -79,35 +86,31 @@ KSameWidget::KSameWidget() : KMainWindow(0)
 	connect( stone, SIGNAL(s_marked(int)), this, SLOT(setMarked(int)));
 	connect( stone, SIGNAL(s_score(int)), this, SLOT(setScore(int)));
 	connect( stone, SIGNAL(s_remove(int,int)), this, SLOT(stonesRemoved(int,int)));
-	
+
 	connect(stone, SIGNAL(s_sizechanged()), this, SLOT(sizeChanged()));
-	
+
 	sizeChanged();
 	setCentralWidget(stone);
 
 	createGUI();
 
-	highscore = new HighScore(this);
-
 	random->setChecked(true);
-	undo->setEnabled(stone->undoPossible());
-	restart->setEnabled(!stone->isOriginalBoard());
+	setScore(0);
 
 	if (!kapp->isRestored()) newGame(kapp->random(),default_colors);
 	kdDebug() << "test" << endl;
 }
 
 KSameWidget::~KSameWidget() {
-	delete highscore;
 }
 
 void KSameWidget::readProperties(KConfig *conf) {
-  ASSERT(conf);
+  Q_ASSERT(conf);
   stone->readProperties(conf);
 }
 
 void KSameWidget::saveProperties(KConfig *conf) {
-  ASSERT(conf);
+  Q_ASSERT(conf);
   stone->saveProperties(conf);
   conf->sync();
 }
@@ -120,10 +123,7 @@ void KSameWidget::newGame(unsigned int board,int colors) {
 	while (board>=1000000) board-=1000000;
 	// kdDebug() << "newgame board " << board << " colors " << colors << endl;
 	stone->newGame(board,colors);
-	//     setBoard(stone->getBoard());
-	//     setColors(stone->getColors());
-	undo->setEnabled(stone->undoPossible());
-	restart->setEnabled(!stone->isOriginalBoard());
+	setScore(0);
 }
 
 bool KSameWidget::confirmAbort() {
@@ -138,40 +138,20 @@ void KSameWidget::m_new() {
 		if (confirmAbort())
 			newGame(kapp->random(),default_colors);
 	} else {
-		QDialog dlg(0, "boardchooser", 1);
-		int w=10,h=10;
+		KDialogBase dlg(this, "boardchooser", true, 
+		                i18n("Select Board"), 
+		                KDialogBase::Ok | KDialogBase::Cancel, 
+		                KDialogBase::Ok);
 		
-		KIntNumInput bno(0, &dlg, 10);
+		QVBox *page = dlg.makeVBoxMainWidget();
+		
+		KIntNumInput bno(0, page);
 		bno.setRange(0, 1000000, 1);
 		bno.setLabel(i18n("Select a board"));
 		bno.setFocus();
-		//    QLabel l(&bno,i18n("Please &enter the board number:"),&dlg);
-		
-		bno.move(10,h);
-		bno.resize(bno.sizeHint());
-		w=bno.width()+20;
-		h+=bno.height()+10;
-		//    bno.move(10,h);
-		//    w=QMAX(bno.width()+20,w);
-		//    h+=bno.height()+10;
-		
-		QPushButton ok(i18n("OK"), &dlg);
-		ok.setDefault(true);
-		QPushButton cancel(i18n("Cancel"), &dlg);
-		
-		w=QMAX(ok.width()+cancel.width()+40,w);
-		
-		ok.move(w-ok.width()-20-cancel.width(),h);
-		cancel.move(w-cancel.width()-10,h);
-		h+=QMAX(ok.height(),cancel.height())+10;
-		
-		dlg.resize(w,h);
-		dlg.setFixedSize(w,h);
-		dlg.connect(&ok, SIGNAL(clicked()), SLOT(accept()) );
-		dlg.connect(&cancel, SIGNAL(clicked()), SLOT(reject()) );
-		dlg.connect(&bno, SIGNAL(returnPressed()), SLOT(accept()) );
+		bno.setFixedSize(bno.sizeHint());
 		bno.setValue(stone->board());
-		//    bno.selectAll();
+
 		if (dlg.exec()) newGame(bno.value(),default_colors);
 	}
 }
@@ -180,7 +160,7 @@ void KSameWidget::m_restart() {
 	if (confirmAbort())
 		newGame(stone->board(),default_colors);
 }
-	
+
 void KSameWidget::m_load() {
   kdDebug() << "menu load not supported" << endl;
 }
@@ -190,21 +170,24 @@ void KSameWidget::m_save() {
 }
 
 void KSameWidget::m_undo() {
-	ASSERT(stone);
+	Q_ASSERT(stone);
 	stone->undo();
 }
 
 
 void KSameWidget::m_showhs() {
-  ASSERT(stone);
+  Q_ASSERT(stone);
   stone->unmark();
-  highscore->showScore();
+  KScoreDialog d(KScoreDialog::Name | KScoreDialog::Score, this);
+  d.addField(Board, i18n("Board"), "Board");
+  d.exec();
 }
 
 void KSameWidget::m_quit() {
-  ASSERT(stone);
+  Q_ASSERT(stone);
   stone->unmark();
   kapp->quit();
+  delete this;
 }
 
 void KSameWidget::m_tglboard() {
@@ -247,5 +230,14 @@ void KSameWidget::gameover() {
 			   "You got a score of %1 in total.").arg(stone->score()));
   }
   stone->unmark();
-  highscore->add(stone->board(),stone->score(),stone->colors());
+  KScoreDialog d(KScoreDialog::Name | KScoreDialog::Score, this);
+  d.addField(Board, i18n("Board"), "Board");
+
+  KScoreDialog::FieldInfo scoreInfo;
+  scoreInfo[Board].setNum(stone->board());
+  
+  if (d.addScore(stone->score(), scoreInfo))
+    d.exec();
 }
+
+#include "KSameWidget.moc"
