@@ -21,7 +21,7 @@
 
 #include <qwidget.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 
