@@ -48,8 +48,9 @@
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qdialog.h>
+#include <qstyle.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kiconloader.h>
 #include <kseparator.h>
 #include <kglobal.h>
@@ -139,6 +140,8 @@ App::App() : KMainWindow(0) {
 App::~App() {
   delete b;
   delete sb;
+  delete highscoreTable;
+
 }
 
 void App::initKAction() {
@@ -148,9 +151,9 @@ void App::initKAction() {
   KStdGameAction::highscores(this, SLOT(hallOfFame()), actionCollection());
   KStdGameAction::pause(this, SLOT(pause()), actionCollection());
 
-  (void)new KAction(i18n("Is game solvable?"), 0, this, SLOT(isSolvable()), actionCollection(), "game_solvable");
-  (void)new KAction(i18n("Res&tart game"), KAccel::stringToKey("CTRL+R"), this, SLOT(restartGame()), actionCollection(), "game_restart");
-  (void)new KAction(i18n("Get &hint"), Key_H, this, SLOT(hint()), actionCollection(), "game_hint");
+  (void)new KAction(i18n("Is Game Solvable?"), 0, this, SLOT(isSolvable()), actionCollection(), "game_solvable");
+  (void)new KAction(i18n("Res&tart Game"), Qt::CTRL+Qt::Key_R, this, SLOT(restartGame()), actionCollection(), "game_restart");
+  (void)new KAction(i18n("Get &Hint"), Key_H, this, SLOT(hint()), actionCollection(), "game_hint");
 
 #ifdef DEBUGGING
   (void)new KAction("&Finish", 0, b, SLOT(finish()), actionCollection(), "game_finish");
@@ -187,7 +190,7 @@ void App::initKAction() {
   level->setItems(list);
 
   (void)new KToggleAction(i18n("G&ravity"), 0, this, SLOT(toggleGravity()), actionCollection(), "options_gravity");
-  (void)new KToggleAction(i18n("Disallow unsolvable games"), 0, this, SLOT(toggleDisallowUnsolvable()), actionCollection(), "options_disallow");
+  (void)new KToggleAction(i18n("Disallow Unsolvable Games"), 0, this, SLOT(toggleDisallowUnsolvable()), actionCollection(), "options_disallow");
   
   createGUI("kshisenui.rc");
 }
@@ -233,6 +236,7 @@ void App::pause() {
 	actionCollection()->action("game_pause")->setText(i18n("R&esume game"));
   else
 	actionCollection()->action("game_pause")->setText(i18n("&Pause game"));
+  actionCollection()->action("game_pause")->setAccel(Qt::Key_P);
 }
 
 void App::undo() {
@@ -404,10 +408,12 @@ QString App::getPlayerName() {
 
   QPushButton *b = new QPushButton(i18n("OK"), dlg);
   b->setDefault(TRUE);
+#if QT_VERSION < 300
   if(style().guiStyle() == MotifStyle)
     b->setFixedSize(b->sizeHint().width() + 10,
 		    b->sizeHint().height() +10);
   else
+#endif
     b->setFixedSize(b->sizeHint());
   connect(b, SIGNAL(released()), dlg, SLOT(accept()));
   connect(e, SIGNAL(returnPressed()), 
@@ -616,7 +622,7 @@ void App::writeHighscore() {
 void App::showHighscore(int focusitem)  {
   // this may look a little bit confusing...
   QDialog *dlg = new QDialog(0, "hall_Of_fame", TRUE);
-  dlg->setCaption(i18n("Shisen-Sho: Hall Of Fame"));
+  dlg->setCaption(i18n("Shisen-Sho: Hall of Fame"));
 
   QVBoxLayout *tl = new QVBoxLayout(dlg, 10);
   
@@ -724,10 +730,12 @@ void App::showHighscore(int focusitem)  {
     }
     
   QPushButton *b = new QPushButton(i18n("Close"), dlg);
+#if QT_VERSION < 300
   if(style().guiStyle() == MotifStyle)
     b->setFixedSize(b->sizeHint().width() + 10,
 		    b->sizeHint().height() + 10);
   else
+#endif
     b->setFixedSize(b->sizeHint());
 
   // connect the "Close"-button to done
