@@ -43,15 +43,15 @@
 #include <qpainter.h>
 #include <qimage.h>
 #include <qtimer.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qbitarray.h>
 #include <qbitmap.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kmessagebox.h>
 
 #include "board.h"
@@ -104,9 +104,10 @@ Board::Board(QWidget *parent) : QWidget(parent) {
 }
 
 Board::~Board() {
-  for(int i = 0; i < 36; i++)
+  for(int i = 0; i < 45; i++)
     if(pm_tile[i])
       delete pm_tile[i];  
+  delete [] field;
 }
 
 int Board::x_tiles() {
