@@ -61,7 +61,7 @@ class Network : public QObject, public Local
 
  public:
 	Network(MPInterface *_interface, QValueList<MPInterface::Data> &_boards,
-			const QList<RemoteHostData> &rhd);
+			const QPtrList<RemoteHostData> &rhd);
 	virtual ~Network();
 
 	virtual uint nbPlayers() const;
@@ -115,7 +115,7 @@ class NetworkServer : public Network, public Server
  public:
 	NetworkServer(MPInterface *_interface,
 				  QValueList<MPInterface::Data> &_boards,
-				  const QList<RemoteHostData> &rhd, uint _interval);
+				  const QPtrList<RemoteHostData> &rhd, uint _interval);
 
 	void writeData(bool inverse);
 	WritingStream *globalStream() { return &stream; }
@@ -139,7 +139,7 @@ class Client : public Network
 
  public:
 	Client(MPInterface *_interface, QValueList<MPInterface::Data> &_boards,
-		   const QList<RemoteHostData> &rhd)
+		   const QPtrList<RemoteHostData> &rhd)
 	: Network(_interface, _boards, rhd) {}
 
 	uint nbPlayers() const { return Local::nbPlayers(); }
