@@ -2,42 +2,33 @@
 
 #include <qmessagebox.h>
 #include <qpushbutton.h>
+
 #include <klocale.h>
 #include <kmessagebox.h>
-#include "netutils.h"
+
 #include "defines.h"
 #include "mp_option.h"
 
 #define LIST_INTERVAL 0
 
-NetMeeting::NetMeeting(const cId &_id, int socket, MPOptionWidget *option,
+
+NetMeeting::NetMeeting(const cId &_id, Socket *socket,
+                       MPOptionWidget *option,
 					   bool _server, QWidget *parent, const char * name)
-: KDialogBase(Plain, i18n("Network meeting"),
+: KDialogBase(Plain, i18n("Network Meeting"),
 			  (_server ? Ok|Cancel|Help : Cancel|Help),
 			  (_server ? Ok : Cancel), parent, name),
   server(_server), ow(option), id(_id), socketRemoved(FALSE)
 {
-	sm.append(socket, SocketManager::ReadWrite, TRUE, this);
+	sm.append(socket, SocketManager::ReadWrite);
 	sm[0]->notifier()->setEnabled(TRUE);
 
-	QLabel *lab;
-	QFont f( font() );
-	f.setBold(TRUE);
-	
 /* top layout */
 	QVBoxLayout *top = new QVBoxLayout(plainPage(), spacingHint());
 	top->setResizeMode(QLayout::Fixed);
-	
-/* title */
-	lab = new QLabel(i18n("Network Meeting"), plainPage());
-	lab->setFont(f);
-	lab->setAlignment(AlignCenter);
-	lab->setFrameStyle(QFrame::Panel | QFrame::Raised);
-	top->addWidget(lab);
-	top->addSpacing(spacingHint());
-	
+
 	// server line
-	spl = new MeetingLine(server, server, plainPage());
+	spl = new MeetingLine(server, server, true, plainPage());
 	top->addWidget(spl);
 
 	// widget list
@@ -48,10 +39,10 @@ NetMeeting::NetMeeting(const cId &_id, int socket, MPOptionWidget *option,
 	labWait = new QLabel(i18n("Waiting for clients"), plainPage());
 	labWait->setAlignment(AlignCenter);
 	top->addWidget(labWait);
-	
+
 	// options widget
 //	if (ow)	top->addWidget(ow); #### FIXME
-	
+
     // status bar
 	status = new QStatusBar(plainPage());
 	status->setSizeGripEnabled(false);
@@ -67,10 +58,13 @@ NetMeeting::NetMeeting(const cId &_id, int socket, MPOptionWidget *option,
 	enableButton(Help, FALSE);
 }
 
+NetMeeting::~NetMeeting()
+{}
+
 void NetMeeting::appendLine(const MeetingLineData &pld, bool server)
 {
 	MeetingLine *pl;
-	pl = new MeetingLine(pld.own, server, wl);
+	pl = new MeetingLine(pld.own, server, false, wl);
 	if (pld.own) connect(pl, SIGNAL(textChanged(const QString &)),
 						 SLOT(textChanged(const QString &)));
 	else message(i18n("A new client has just arrived (#%1)")
@@ -110,7 +104,7 @@ void NetMeeting::setType(const TypeInfo &ti)
 }
 
 void NetMeeting::setText(const TextInfo &ti)
-{	
+{
 	if ( ti.i==0 ) spl->setText(ti.text);
 	else wl->widget(ti.i-1)->setText(ti.text);
 }
@@ -142,7 +136,8 @@ void NetMeeting::cleanReject(const QString &str)
 // Read incoming data
 void NetMeeting::readNotifier(int fd)
 {
-	uint i = sm.find(fd);
+	int i = sm.find(fd);
+    Q_ASSERT( i!=-1 );
 	switch ( sm[i]->read() ) {
 	 case -1: readError(i);  break;
 	 case  0: brokeError(i); break;
@@ -156,7 +151,6 @@ void NetMeeting::readData(uint i)
 	MeetingMsgFlag mt;
 	sm[i]->readingStream() >> mt;
 	CHECK_READ(i);
-
 	switch (mt) {
 	 case End:      endFlag(i);     break;
 	 case New:      newFlag(i);     break;
@@ -168,7 +162,7 @@ void NetMeeting::readData(uint i)
 	 case Play:     playFlag(i);    break;
 	 default:       dataError(i);
 	}
-	
+
 	if (socketRemoved) socketRemoved = FALSE;
 	else if ( !sm[i]->readingStream().atEnd() )
 		readData(i); // more pending data
@@ -202,10 +196,15 @@ void NetMeeting::reject()
 	// send an End flag
 	sm.commonWritingStream() << End;
 	writeToAll();
-	
+
 	cleanReject();
 }
 
+void NetMeeting::accept()
+{
+    KDialogBase::accept();
+}
+
 void NetMeeting::message(const QString &str)
 {
 	status->message(str, 3000);
@@ -214,18 +213,18 @@ void NetMeeting::message(const QString &str)
 /** ServerNetMeeting *********************************************************/
 ServerNetMeeting::ServerNetMeeting(const cId &id,
 	const RemoteHostData &r, MPOptionWidget *option,
-	QList<RemoteHostData> &arhd, QWidget *parent, const char * name)
+	QPtrList<RemoteHostData> &arhd, QWidget *parent, const char * name)
 : NetMeeting(id, r.socket, option, TRUE, parent, name), rhd(arhd)
 {
 	connect(sm[0]->notifier(), SIGNAL(activated(int)), SLOT(newHost(int)));
 	players.append(Accepted); // server
-	
+
 	// set server line
 	ExtData ed(r.bds, "", MeetingCheckBox::Ready);
 	spl->setData(ed);
 	connect(spl, SIGNAL(textChanged(const QString &)),
 			SLOT(textChanged(const QString &)));
-	
+
 	// options signal
 	if (ow) connect(ow, SIGNAL(changed()), SLOT(optionsChanged()));
 }
@@ -241,13 +240,13 @@ void ServerNetMeeting::writeToAll(uint i)
 
 void ServerNetMeeting::netError(uint i, const QString &type)
 {
-	ASSERT( i!=0 );
+	Q_ASSERT( i!=0 );
 	disconnectHost(i, i18n("%1 client #%2 : disconnect it").arg(type).arg(i));
 }
 
 void ServerNetMeeting::disconnectHost(uint i, const QString &str)
 {
-	sm.remove(i);
+	sm.remove(i, true);
 	socketRemoved = TRUE;
 	if ( players[i]==Accepted ) {
 		removeLine(i-1);
@@ -262,38 +261,42 @@ void ServerNetMeeting::disconnectHost(uint i, const QString &str)
 
 void ServerNetMeeting::newHost(int)
 {
-	int fd;
-	QString tmp1, tmp2;
-	if ( !acceptInetSocket(sm[0]->fd(), fd, tmp1, tmp2) ) {
-		message(i18n("Failed to accept incoming client"));
-		return;
-	}
+    KExtendedSocket *s;
+    int res = sm[0]->accept(s);
+    if ( res!=0 ) {
+        message(i18n("Failed to accept incoming client:\n%1")
+                .arg(socketError(s)));
+        return;
+    }
 	players.append(NewPlayer);
-	uint i = sm.append(fd, SocketManager::ReadWrite, TRUE, this);
-	connect(sm[i]->notifier(), SIGNAL(activated(int)), SLOT(readNotifier(int)));
+    Socket *socket = new Socket(s, true);
+	uint i = sm.append(socket, SocketManager::ReadWrite);
+	connect(sm[i]->notifier(), SIGNAL(activated(int)),
+            SLOT(readNotifier(int)));
 	sm[i]->notifier()->setEnabled(TRUE);
 }
 
 void ServerNetMeeting::idFlag(uint i)
 {
 	bool b = checkAndSetState(i, NewPlayer, IdChecked);
-	ASSERT(b);
-	
+	Q_ASSERT(b);
+
 	// get client id
 	cId clientId;
 	sm[i]->readingStream() >> clientId;
 	CHECK_READ(i);
-	
+
 	// compare id
 	id.check(clientId);
-	
+
 	// send result to client
 	Stream &s = sm[i]->writingStream();
 	s << Id << id;
 	WRITE(i);
-	
+
 	// if not accepted : remove socket and player from list
-	if ( !id.accepted() ) disconnectHost(i, i18n("Client rejected for incompatible ID"));
+	if ( !id.accepted() )
+        disconnectHost(i, i18n("Client rejected for incompatible ID"));
 }
 
 void ServerNetMeeting::endFlag(uint i)
@@ -304,7 +307,7 @@ void ServerNetMeeting::endFlag(uint i)
 void ServerNetMeeting::newFlag(uint i)
 {
 	checkAndSetState(i, IdChecked, Accepted);
-	
+
 	// get line infos from new client (GameData struct)
 	MeetingLineData pld;
 	sm[i]->readingStream() >> pld.ed.bds;
@@ -326,7 +329,7 @@ void ServerNetMeeting::newFlag(uint i)
 		sm[i]->writingStream() << New << pld;
 	}
 	WRITE(i);
-	
+
 	// send to all other clients the new line (New flag + MeetingLineData struct)
 	wl->widget(i-1)->data(pld.ed);
 	pld.own = FALSE;
@@ -337,14 +340,14 @@ void ServerNetMeeting::newFlag(uint i)
 void ServerNetMeeting::modTextFlag(uint i)
 {
 	checkState(i-1, Accepted);
-	
+
 	// the client i has just sent a new text (QString)
 	TextInfo ti;
 	sm[i]->readingStream() >> ti.text;
 	CHECK_READ(i);
 	ti.i = i;
 	setText(ti);
-	
+
 	// send it to all other clients (Mod_Text flag + TextInfo struct)
 	sm.commonWritingStream() << Mod_Text << ti;
 	writeToAll(i);
@@ -353,14 +356,14 @@ void ServerNetMeeting::modTextFlag(uint i)
 void ServerNetMeeting::modTypeFlag(uint i)
 {
 	checkState(i-1, Accepted);
-	
+
 	// a client has just sent a new TCB type (TCB type)
 	TypeInfo ti;
 	sm[i]->readingStream() >> ti.type;
 	CHECK_READ(i);
 	ti.i = i;
 	setType(ti);
-	
+
 	// send it to all other clients (Mod_Type flag + TypeInfo struct)
 	sm.commonWritingStream() << Mod_Type << ti;
 	writeToAll(i);
@@ -376,16 +379,16 @@ void ServerNetMeeting::textChanged(const QString &text)
 
 void ServerNetMeeting::typeChanged(MeetingCheckBox::Type type)
 {
-	ASSERT( sender()!=spl ); // server TCB not modifiable
+	Q_ASSERT( sender()!=spl ); // server TCB not modifiable
 	// the server has changed a client TCB
-	
+
 	// find the changed TCB index
 	TypeInfo ty;
 	ty.type = type;
 	for (ty.i=0; ty.i<wl->size(); ty.i++)
 		if ( sender()==wl->widget(ty.i) ) break;
 	ty.i++;
-	
+
 	// TCB change : send to every clients (Mod_Type flag + TypeInfo struct)
 	sm.commonWritingStream() << Mod_Type << ty;
 	writeToAll();
@@ -394,43 +397,45 @@ void ServerNetMeeting::typeChanged(MeetingCheckBox::Type type)
 
 void ServerNetMeeting::accept()
 {
-	ASSERT( ready() && rhd.count()==0 );
+	Q_ASSERT( ready() && rhd.count()==0 );
 
 	// stop receiving data from clients (will be buffered by OS)
 	for (uint k=0; k<sm.size(); k++) disconnect(sm[k]->notifier());
-	sm.remove(0);
-	
+	sm.remove(0, true);
+
 	// check which client will play and fill RemoteHostData array
 	ExtData ed;
 	bool willPlay;
 	for (uint k=1; k<players.count(); k++) {
 		willPlay = FALSE;
-		
+
 		if ( players[k]==Accepted ) { // client with lines
 				wl->widget(k-1)->data(ed);
 			if ( ed.type==MeetingCheckBox::Ready ) {
 				willPlay  = TRUE;
 				RemoteHostData *r = new RemoteHostData;
-				r->socket = sm[0]->fd();
+				r->socket = sm[0];
 				r->bds    = ed.bds;
 				rhd.append(r);
 			}
-				
+
 			// send play message to client (Play flag
 			// + bool [accepted/rejected])
 			sm[0]->writingStream() << Play << (Q_UINT8)willPlay;
 			// if write failed and the client is not playing : silently
 			// put it aside ...
 			if ( !sm[0]->write() && willPlay ) {
-				cleanReject(i18n("Cannot write to client #%1 at game beginning"));
+				cleanReject(i18n("Cannot write to client #%1 at game "
+                                 "beginning."));
 				return;
 			}
 		}
-		
-		sm.remove(0, !willPlay); // do not close player sockets	
+
+        sm[0]->notifier()->setEnabled(false);
+		sm.remove(0, !willPlay);
 	}
-	
-	KDialogBase::accept();
+
+	NetMeeting::accept();
 }
 
 void ServerNetMeeting::optionsChanged()
@@ -449,7 +454,7 @@ ClientNetMeeting::ClientNetMeeting(const cId &id,
 	connect(sm[0]->notifier(), SIGNAL(activated(int)),
 			SLOT(readNotifier(int)));
 	players.append(NewPlayer); // server player
-	
+
 	// Send id to server (Id flag + Id struct)
 	sm.commonWritingStream() << Id << id;
 	writeToAll(); // what happens if there is a message box appearing before exec() call ??
@@ -457,7 +462,7 @@ ClientNetMeeting::ClientNetMeeting(const cId &id,
 
 void ClientNetMeeting::netError(uint, const QString &str)
 {
-	cleanReject(i18n("%1 server : aborting connection").arg(str));
+	cleanReject(i18n("%1 server: aborting connection.").arg(str));
 }
 
 void ClientNetMeeting::writeToAll(uint)
@@ -469,12 +474,12 @@ void ClientNetMeeting::writeToAll(uint)
 void ClientNetMeeting::idFlag(uint)
 {
 	checkAndSetState(0, NewPlayer, IdChecked);
-	
+
 	// read Id result (Id flag + Id struct)
 	cId serverId;
 	sm[0]->readingStream() >> serverId;
 	CHECK_READ(0);
-	
+
 	// check result
 	if ( !serverId.accepted() ) cleanReject(serverId.errorMessage(id));
 	else {
@@ -547,13 +552,12 @@ void ClientNetMeeting::playFlag(uint)
 	Q_UINT8 i;
 	sm[0]->readingStream() >> i;
 	CHECK_READ(0);
-	
-	if (i) {
-		sm.remove(0, FALSE); // do not close it
-		socketRemoved = TRUE;
-		accept();
-	} else cleanReject(i18n("the game has begun without you\n"
-							"(you have been excluded by the server)"));
+    sm[0]->notifier()->setEnabled(false);
+    sm.remove(0, i==0);
+    socketRemoved = true;
+	if (i) accept();
+	else cleanReject(i18n("The game has begun without you\n"
+                          "(You have been excluded by the server)."));
 }
 
 void ClientNetMeeting::modOptFlag(uint)
@@ -566,5 +570,6 @@ void ClientNetMeeting::modOptFlag(uint)
 void ClientNetMeeting::endFlag(uint)
 {
 	// abort from server
-	cleanReject(i18n("the server has aborted the game"));
+	cleanReject(i18n("The server has aborted the game."));
 }
+#include "meeting.moc"
