@@ -4,7 +4,7 @@
 #include <qwidget.h>
 #include <qlayout.h>
 #include <qtimer.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kaccel.h>
 
 #include "mp_board.h"
@@ -96,7 +96,7 @@ class MPInterface : public QWidget
 	void dialog();
 	
 	/** Configure keys for current number of human players. */
-	void configureKeys();
+	virtual void configureKeys();
 	
  public:
 	/** Called when a new game is created. At this point
@@ -115,10 +115,10 @@ class MPInterface : public QWidget
 				   const char *member);
 
 	/** Set keys configuration for the given number of human players.
-	 *  The size of the "const char **" QArray must be the number of humans.
+	 *  The size of the "const char **" QMemArray must be the number of humans.
 	 *  The size of	the "const char *" array is the number of defined actions.
 	 */
-	void setKeysConfiguration(const QArray<const char **> &defaultKeys);
+	void setKeysConfiguration(const QMemArray<const char **> &defaultKeys);
 	
 	/** @return the total number of players.
 	  * (If called from client : return the number of local boards).
@@ -226,9 +226,9 @@ class MPInterface : public QWidget
 	
 	KAccel             *kacc;
 	KeyConnection      *kcn;
-	QArray<KeyConfData> kcf;
+	QMemArray<KeyConfData> kcf;
 
-	void createServerGame(const QList<RemoteHostData> &);
+	void createServerGame(const QPtrList<RemoteHostData> &);
 	void createClientGame(const RemoteHostData &);
 	void createLocalGame(const ConnectionData &);
 	void specialLocalGame(uint nbHumans, uint nbComputers);
