@@ -31,13 +31,13 @@ void MPSimpleBoard::initFlag(QDataStream &s)
 
 void MPSimpleBoard::playFlag(QDataStream &s)
 {
-	ASSERT( state==BS_Play );
+	Q_ASSERT( state==BS_Play );
 	_playFlag(s);
 }
 
 void MPSimpleBoard::pauseFlag()
 {
-	ASSERT( state==BS_Play || state==BS_Pause );
+	Q_ASSERT( state==BS_Play || state==BS_Pause );
 	bool p = ( state==BS_Pause );
 	state  = (p ? BS_Play : BS_Pause);
 	emit activateKeys(p);
@@ -46,7 +46,7 @@ void MPSimpleBoard::pauseFlag()
 
 void MPSimpleBoard::gameOverFlag()
 {
-	ASSERT( BS_Play );
+	Q_ASSERT( BS_Play );
 	_stop(TRUE);
 	state = BS_Stop;
 }
