@@ -3,6 +3,11 @@
 #include <kmessagebox.h>
 #include <qtimer.h>
 #include <klocale.h>
+#include <kaction.h>
+#include <kmainwindow.h>
+
+#define PAUSE_ACTION \
+    ((KToggleAction *)((KMainWindow *)topLevelWidget())->action("game_pause"))
 
 MPSimpleInterface::MPSimpleInterface(const MPGameInfo &gi, KAccel *kacc,
 									 QWidget *parent, const char *name)
@@ -35,13 +40,23 @@ void MPSimpleInterface::stop(bool server)
 	immediateWrite();
 }
 
+void MPSimpleInterface::configureKeys()
+{
+    if ( !isPaused() ) pause();
+    MPInterface::configureKeys();
+}
+
 void MPSimpleInterface::pause()
 {
 	// WARNING : multiple calls can happen here (because button
 	// hiding is delayed)
 	switch (state) {
-	 case SS_Play:  state = SS_PauseAsked; break;
-	 case SS_Pause: state = SS_UnpauseAsked; break;
+	 case SS_Play:
+         state = SS_PauseAsked;
+         break;
+	 case SS_Pause:
+         state = SS_UnpauseAsked;
+         break;
 	 default: break;
 	}
 }
@@ -49,7 +64,7 @@ void MPSimpleInterface::pause()
 void MPSimpleInterface::dataFromServer(QDataStream &s)
 {
 	if ( s.atEnd() ) return; // no data
-	
+
 	SC_Flag scf;
 	s >> scf;
 	switch (scf.value()) {
@@ -80,7 +95,7 @@ void MPSimpleInterface::treatData()
 void MPSimpleInterface::treatInit()
 {
 	state = SS_Play;
-	
+
 	if (first_init) {
 		_firstInit();
 		first_init = FALSE;
@@ -93,6 +108,9 @@ void MPSimpleInterface::treatInit()
 
 void MPSimpleInterface::treatPlay()
 {
+    PAUSE_ACTION->setEnabled(true);
+    PAUSE_ACTION->setChecked(false);
+
 	bool end = _readPlayData();
 	if (end) {
 		state = SS_Stop;
@@ -111,16 +129,23 @@ void MPSimpleInterface::treatPause(bool pause)
 	state = (pause ? SS_Pause : SS_Play);
 	IO_Flag f(IO_Flag::Pause);
 	for (uint i=0; i<nbPlayers(); i++) writingStream(i) << f;
+
+    PAUSE_ACTION->setChecked(pause);
 }
 
 void MPSimpleInterface::treatStop()
 {
 	state = SS_Standby;
-	
+
 	// read game over data + send them to all clients
 	QDataStream &s = dataToClientsStream();
 	SC_Flag f(SC_Flag::GameOver);
 	s << f;
 	_sendGameOverData(s);
 	_showGameOverData(TRUE);
+
+    PAUSE_ACTION->setEnabled(false);
+    PAUSE_ACTION->setChecked(false);
 }
+
+#include "mp_simple_interface.moc"
