@@ -7,14 +7,17 @@
 class MPSimpleInterface : public MPInterface
 {
  Q_OBJECT
-		
+
  public:
 	MPSimpleInterface(const MPGameInfo &gi, KAccel *kacc,
 					  QWidget *parent = 0, const char *name = 0);
-	
+
+    bool isPaused() const { return state==SS_Pause; }
+
  public slots:
 	void start();
 	void pause();
+	void configureKeys();
 
  protected:
 	virtual void _init(bool server) = 0;
@@ -25,7 +28,7 @@ class MPSimpleInterface : public MPInterface
 	virtual void _treatInit() = 0;
 	virtual bool _readPlayData() = 0;
 	virtual void _sendPlayData() = 0;
-	
+
  private:
 	ServerState state;
 	bool        first_init;
