@@ -4,7 +4,7 @@
 #include "version.h"
 
 cId::cId(const QString &_gameName, const QString &_gameId)
-: libId(LIB_ID), gameName(_gameName), gameId(_gameId)
+: libId(MULTI_ID), gameName(_gameName), gameId(_gameId)
 {}
 
 void cId::check(const cId &id)
@@ -18,10 +18,10 @@ void cId::check(const cId &id)
 QString cId::errorMessage(const cId &id) const
 {
 	QString str = i18n("\nserver : \"%1\"\nclient : \"%2\"");
-	
+
 	switch (state) {
 	 case Accepted: return QString::null;
-	 case LibIdClash: 
+	 case LibIdClash:
 		return i18n("The MultiPlayer library of the server is incompatible")
 			+ str.arg(libId).arg(id.libId);
 	 case GameNameClash:
@@ -31,7 +31,7 @@ QString cId::errorMessage(const cId &id) const
 		return i18n("The server game version is incompatible")
 			+ str.arg(gameId).arg(id.gameId);
 	}
-	ASSERT(0);
+	Q_ASSERT(0);
 	return QString::null;
 }
 
@@ -63,7 +63,7 @@ QDataStream &operator >> (QDataStream &s, MeetingMsgFlag &f)
 	return s;
 }
 
-//-----------------------------------------------------------------------------	
+//-----------------------------------------------------------------------------
 QDataStream &operator << (QDataStream &s, const TextInfo &ti)
 {
 	s << (Q_UINT32)ti.i << ti.text;
@@ -91,20 +91,6 @@ QDataStream &operator >> (QDataStream &s, MeetingCheckBox::Type &t)
 	return s;
 }
 
-//-----------------------------------------------------------------------------
-//QDataStream &operator << (QDataStream &s, const PlayerCheckBox::Type &t)
-//{
-//	s << (Q_UINT8)t;
-//	return s;
-//}
-
-//QDataStream &operator >> (QDataStream &s, PlayerCheckBox::Type &t)
-//{
-//	Q_UINT8 i;
-//	s >> i; t = (PlayerCheckBox::Type)i;
-//	return s;
-//}
-
 //-----------------------------------------------------------------------------
 QDataStream &operator << (QDataStream &s, const TypeInfo &ti)
 {
@@ -122,13 +108,15 @@ QDataStream &operator >> (QDataStream &s, TypeInfo &ti)
 //-----------------------------------------------------------------------------
 QDataStream &operator << (QDataStream &s, const BoardData &bd)
 {
-	s << bd.type << bd.name;
+	s << (Q_UINT8)bd.type << bd.name;
 	return s;
 }
 
 QDataStream &operator >> (QDataStream &s, BoardData &bd)
 {
-	s >> (MeetingCheckBox::Type&) bd.type >> bd.name;
+    Q_UINT8 i;
+	s >> i >> bd.name;
+    bd.type = (PlayerComboBox::Type)i;
 	return s;
 }
 
@@ -138,7 +126,7 @@ QDataStream &operator << (QDataStream &s, const ExtData &ed)
 	s << ed.bds << ed.text << ed.type;
 	return s;
 }
-	
+
 QDataStream &operator >> (QDataStream &s, ExtData &ed)
 {
 	s >> ed.bds >> ed.text >> ed.type;
@@ -151,7 +139,7 @@ QDataStream &operator << (QDataStream &s, const MeetingLineData &pld)
 	s << pld.ed << (Q_UINT8)pld.own;
 	return s;
 }
-	
+
 QDataStream &operator >> (QDataStream &s, MeetingLineData &pld)
 {
 	Q_UINT8 b;
@@ -179,7 +167,7 @@ Stream::Stream(int _mode)
 : mode(_mode)
 {
 	setDevice(&buf);
-	ASSERT( _mode==IO_ReadOnly || _mode==IO_WriteOnly );
+	Q_ASSERT( _mode==IO_ReadOnly || _mode==IO_WriteOnly );
 	buf.open(_mode);
 }
 
