@@ -13,13 +13,13 @@
 #include <qcolor.h>
 #include <qpopupmenu.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kmenubar.h>
 #include <klocale.h>
 #include <kconfig.h>
-#include <kcolordlg.h>
+#include <kcolordialog.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 
@@ -54,7 +54,7 @@ Game::Game() :  KMainWindow(0)
     menu();
     checkMenuItems();
 
-    View *view = new View(this);
+    View *view = new View(this); //Lots of stuff happens in View::View - namely rattler creation
     rattler = view->rattler;
     rattler->reloadRoomPixmap();
     rattler->setFocus();
@@ -79,8 +79,8 @@ void Game::menu()
     pause = new KAction(i18n("&Pause"), Key_F3, this, SLOT(pauseGame()),
 			actionCollection(), "game_pause");
     new KAction(i18n("&Show Highscores..."), CTRL+Key_H, this, SLOT(showHighScores()),
-		actionCollection(), "game_highscore");
-    KStdAction::quit(this, SLOT(quitGame()), actionCollection(), "game_exit");
+		actionCollection(), "game_highscores");
+    KStdAction::quit(this, SLOT(quitGame()), actionCollection(), "game_quit");
 
     skills[0] = new KRadioAction(i18n("Beginner"), 0, this, SLOT(skillChecked()),
 				 actionCollection(), "opt_beginner");
@@ -105,11 +105,11 @@ void Game::menu()
 	ballsAI = new KSelectAction(i18n("Balls AI"), 0, this, SLOT(ballsAIChecked()),
 			actionCollection(), "opt_ballsai");
 	QStringList bai;
-	bai.append("Default");
-	bai.append("Dumb");
-	bai.append("Killer");
+	bai.append(i18n("Default"));
+	bai.append(i18n("Dumb"));
+	bai.append(i18n("Killer"));
 	ballsAI->setItems(bai);
-	
+
     snakes = new KSelectAction(i18n("&Snakes"), 0, this, SLOT(snakesChecked()),
 				actionCollection(), "opt_snakes");
     snakes->setItems(list);
@@ -117,17 +117,17 @@ void Game::menu()
 	snakesAI = new KSelectAction(i18n("Snakes AI"), 0, this, SLOT(snakesAIChecked()),
 			actionCollection(), "opt_snakesai");
 	QStringList sai;
-	sai.append("Random");
-	sai.append("Eater");
-	sai.append("Killer");
+	sai.append(i18n("Random"));
+	sai.append(i18n("Eater"));
+	sai.append(i18n("Killer"));
 	snakesAI->setItems(sai);
-	
-    new KAction(i18n("Change keys..."),0, this, SLOT(confKeys()),
+
+    new KAction(i18n("Change Keys..."),0, this, SLOT(confKeys()),
 		actionCollection(), "opt_change_keys");
     new KAction(i18n("Starting Room..."), 0, this, SLOT(startingRoom()),
 		actionCollection(), "opt_startroom");
 
-    new KAction(i18n("Select background color..."), 0, this, SLOT(backgroundColor()),
+    new KAction(i18n("Select Background Color..."), 0, this, SLOT(backgroundColor()),
 		actionCollection(), "opt_select_background");
 
     lookupBackgroundPixmaps();
@@ -146,7 +146,7 @@ void Game::menu()
 	    list.append(s);
 	}
     }
-    pix = new KSelectAction(i18n("Select background pixmap"), 0, this, SLOT(pixChecked()),
+    pix = new KSelectAction(i18n("Select Background Pixmap"), 0, this, SLOT(pixChecked()),
 			    actionCollection(), "opt_backgrounds");
     pix->setItems(list);
     createGUI();
