@@ -1,13 +1,13 @@
 #include <qdatetime.h>
 #include <stdlib.h>
 #include <qtimer.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qcolor.h>
 #include <qlabel.h>
 #include <qkeycode.h>
 #include <qbitarray.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kaccel.h>
 
 #include "rattler.h"
@@ -21,7 +21,6 @@
 #include <kconfig.h>
 #include <kmessagebox.h>
 
-
 QBitArray gameState(5);
 QLabel *label = 0;
 //int speed[4] = { 85, 75, 55, 40 };
@@ -34,7 +33,9 @@ Rattler::Rattler( QWidget *parent, const char *name )
     KConfig *conf = kapp->config();
     conf->setGroup("General");
     numBalls = conf->readNumEntry("Balls", 1);
+	ballsAI = conf->readNumEntry("BallsAI", 0);
     numSnakes = conf->readNumEntry("ComputerSnakes", 1);
+	snakesAI = conf->readNumEntry("SnakesAI", 0);
     skill = conf->readNumEntry("Skill", 1);
     room = conf->readNumEntry("StartingRoom", 1);
 
@@ -49,10 +50,10 @@ Rattler::Rattler( QWidget *parent, const char *name )
     basket = new Basket(board, pix);
     samy = new SamySnake(board, pix);
 
-    computerSnakes = new QList<CompuSnake>;
+    computerSnakes = new QPtrList<CompuSnake>;
     computerSnakes->setAutoDelete( TRUE );
 
-    balls = new QList<Ball>;
+    balls = new QPtrList<Ball>;
     balls->setAutoDelete( TRUE );
 
     connect( samy, SIGNAL(closeGate(int)), this, SLOT(closeGate(int)));
@@ -123,21 +124,20 @@ void Rattler::initKeys()
     conf->setGroup("General");
 
     QString up("Up");
-    up = conf->readEntry("upKey", up);
+	up = conf->readEntry("upKey1", up);
     UpKey    = KAccel::stringToKey(up);
 
     QString down("Down");
-    down = conf->readEntry("downKey", down);
+	down = conf->readEntry("downKey1", down);
     DownKey  = KAccel::stringToKey(down);
 
     QString left("Left");
-    left = conf->readEntry("leftKey", left);
+	left = conf->readEntry("leftKey1", left);
     LeftKey  = KAccel::stringToKey(left);
 
     QString right("Right");
-    right = conf->readEntry("rightKey", right);
+	right = conf->readEntry("rightKey1", right);
     RightKey = KAccel::stringToKey(right);
-
 }
 
 void Rattler::keyPressEvent( QKeyEvent *k )
@@ -154,6 +154,13 @@ void Rattler::keyPressEvent( QKeyEvent *k )
 	direction = E;
     else if (key == LeftKey)
 	direction = W;
+    else if ((key == Key_Return) || (key == Key_Enter) || (key == Key_Space)) {
+        if (!gameState.testBit(Demo)) {
+           k->ignore();
+           return;
+        }
+        restart();
+    }
     else {
 	k->ignore();
 	return;
@@ -161,6 +168,46 @@ void Rattler::keyPressEvent( QKeyEvent *k )
     k->accept();
 
 }
+void Rattler::mousePressEvent( QMouseEvent *e )
+{
+    if (gameState.testBit(Paused))
+	return;
+    uint button = e->button();
+    if (button == Qt::RightButton)
+    {
+    	switch (direction)
+	{
+	case N: direction=E;
+		break;
+	case E: direction=S;
+		break;
+	case S: direction=W;
+		break;
+	case W: direction=N;
+		break;
+	}
+	e->accept();
+    }
+    else if (button == Qt::LeftButton)
+    {
+    	switch (direction)
+	{
+	case N: direction=W;
+		break;
+	case E: direction=N;
+		break;
+	case S: direction=E;
+		break;
+	case W: direction=S;
+		break;
+	}
+	e->accept();
+    }
+    else
+    	e->ignore();
+
+}
+
 
 void Rattler::closeGate(int i)
 {
@@ -248,14 +295,14 @@ void Rattler::pause()
 	label->setFrameStyle( QFrame::Panel | QFrame::Raised );
 	label->setGeometry(182, 206, 198, 80);
 	label->show();
-	emit togglePaused();
+	//emit togglePaused();
     }
     else if (gameState.testBit(Paused)) {
 	gameState.toggleBit(Paused);
 	gameState.setBit(Playing);
 	start();
 	cleanLabel();
-	emit togglePaused();
+	//emit togglePaused();
     }
 }
 
@@ -318,14 +365,13 @@ void Rattler::restart()
 	switch( KMessageBox::questionYesNo( this,
 					    i18n("A game is already started.\n"
 						 "Start a new one?\n"),  i18n("Snake Race"))) {
-	case KMessageBox::Yes:
-	    if ( gameState.testBit(Paused))
-		emit togglePaused();
-	    break;
 	case KMessageBox::No:
-	    if ( !gameState.testBit(Paused))
-		start();
-	    return;
+		if (!gameState.testBit(Paused))
+			 start();
+	    	return;
+	    break;
+	case KMessageBox::Yes:
+		;
 	}
     }
 
@@ -439,7 +485,9 @@ void Rattler::init(bool play)
     basket->newApples();
     restartBalls(play);
     restartComputerSnakes(play);
-    if(play) samy->init();
+	if(play) {
+		samy->init();
+	}
 
 }
 
@@ -473,7 +521,18 @@ void Rattler::restartComputerSnakes(bool play)
     int i  = (play == FALSE && numSnakes == 0 ? 1 : numSnakes);
 
     for (int x = 0; x < i; x++) {
-	CompuSnake *as = new CompuSnake(board, pix);
+		CompuSnake *as;
+		switch(snakesAI) {
+			default: // random.
+				as = new CompuSnake(board, pix);
+				break;
+			case 1: // eater.
+				as = new EaterCompuSnake(board, pix);
+				break;
+			case 2: // killer.
+				as = new KillerCompuSnake(board, pix);
+				break;
+		}
 	connect( as, SIGNAL(closeGate(int)), this, SLOT(closeGate(int)));
 	connect( as, SIGNAL(restartTimer()), this, SLOT(restartTimer()));
 	connect( as, SIGNAL(score(bool, int)), this, SLOT(scoring(bool,int)));
@@ -490,7 +549,18 @@ void Rattler::restartBalls(bool play)
     int i = (play == FALSE && numBalls == 0 ? 1 : numBalls);
 
     for (int x = 0; x < i; x++) {
-	Ball *b = new Ball(board, pix);
+		Ball *b;
+		switch(ballsAI) {
+			default: // default.
+				b = new Ball(board, pix);
+				break;
+			case 1: // dumb.
+				b = new DumbKillerBall(board, pix);
+				break;
+			case 2: // smart.
+				b = new KillerBall(board, pix);
+				break;
+		}
 	balls->append(b);
     }
 }
@@ -520,6 +590,11 @@ void Rattler::setBalls(int i)
     }
 }
 
+void Rattler::setBallsAI(int i)
+{
+	ballsAI = i;
+}
+
 void  Rattler::resizeEvent( QResizeEvent * )
 {
 
@@ -538,7 +613,18 @@ void Rattler::setCompuSnakes(int i)
     if (gameState.testBit(Playing) || gameState.testBit(Demo)) {
 	if ( i > count) {
 	    while ( i > count) {
-		CompuSnake *as = new CompuSnake(board, pix);
+				CompuSnake *as;
+				switch(snakesAI) {
+					default: // random.
+						as = new CompuSnake(board, pix);
+						break;
+					case 1: // eater.
+						as = new EaterCompuSnake(board, pix);
+						break;
+					case 2: // killer.
+						as = new KillerCompuSnake(board, pix);
+						break;
+				}
 		connect( as, SIGNAL(closeGate(int)), this, SLOT(closeGate(int)));
 		connect( as, SIGNAL(restartTimer()), this, SLOT(restartTimer()));
 		connect( as, SIGNAL(score(bool, int)), this, SLOT(scoring(bool,int)));
@@ -558,6 +644,11 @@ void Rattler::setCompuSnakes(int i)
     }
 }
 
+void Rattler::setSnakesAI(int i)
+{
+	snakesAI = i;
+}
+
 void Rattler::setSkill(int i)
 {
     skill = i;
