@@ -12,7 +12,7 @@
 #include <qlineedit.h>
 
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 #include "score.h"
 #include <klocale.h>
@@ -196,19 +196,19 @@ ScoreBox::ScoreBox( QWidget *parent, const char *name , int current)
     for ( int x = 0; x < 5; x++) {
 
 	QLabel *l = new QLabel(this);
-	CHECK_PTR(l);
+	Q_CHECK_PTR(l);
 	l->setFont( QFont( "times", 10) );
 	l->setAlignment( AlignRight );
 	date[x] = l;
 
 	QLabel *l1 = new QLabel(this);
-	CHECK_PTR(l1);
+	Q_CHECK_PTR(l1);
 	l1->setFont( QFont( "times", 14) );
 	l1->setAlignment( AlignRight );
 	points[x] = l1;
 
 	QLabel *l2 = new QLabel(this);
-	CHECK_PTR(l2);
+	Q_CHECK_PTR(l2);
 	l2->setFont( QFont( "times", 14) );
 	l2->setAlignment( AlignLeft );
 	player[x] = l2;
