@@ -1,6 +1,6 @@
 #include <qpushbutton.h>
 #include <qlabel.h>
-#include <qcombo.h>
+#include <qcombobox.h>
 #include <qtabwidget.h>
 #include <qslider.h>
 #include <qlcdnumber.h>
@@ -13,7 +13,7 @@
 #include <kmessagebox.h>
 #include <kconfig.h>
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kaccel.h>
 
 #include "dialogs.h"
@@ -47,7 +47,7 @@ KeySetup::KeySetup(SOptions *opt,QWidget *parent,const char *name)
       button[p][PlayerKeyMine]=new QPushButton(i18n("Verb","Mine"),bplayer[p]);
       for(i=0;i<PlayerKeyNum;i++)
       {
-         keyName[p][i]=new QLabel(KAccel::keyToString((unsigned)key[p][i],true),bplayer[p]);
+         keyName[p][i]=new QLabel(KKey(key[p][i]).toString(),bplayer[p]);
          keyName[p][i]->setLineWidth(1);
          keyName[p][i]->setFrameStyle(QFrame::Sunken|QFrame::Panel);
          keyName[p][i]->setMinimumSize( 80, 10 );
@@ -117,7 +117,7 @@ void KeySetup::slotDefault()
 
    for(p=0;p<2;p++)
       for(i=0;i<PlayerKeyNum;i++)
-         keyName[p][i]->setText(KAccel::keyToString(key[p][i], true));
+         keyName[p][i]->setText(KKey(key[p][i]).toString());
 }
 
 void KeySetup::slotOk()
@@ -139,7 +139,7 @@ void KeySetup::slotOk()
    }
    if(sameKey)
      sameKey = KMessageBox::warningContinueCancel(this,
-         i18n("There are multiple functions for a key\n"
+         i18n("There are multiple functions for a key.\n"
               "Continue?"),
 	      i18n("Key Setup"), i18n("&OK"))
        == KMessageBox::Cancel;
@@ -148,7 +148,7 @@ void KeySetup::slotOk()
       for(p=0;p<2;p++)
          for(i=0;i<PlayerKeyNum;i++)
             options->playerKey[p][i]=key[p][i];
-      
+
       accept();
    }
 }
@@ -210,7 +210,7 @@ void KeySetup::keyPressEvent(QKeyEvent *ev)
       if(player<2)
       {
          key[player][waitForKey]=ev->key();
-         keyName[player][waitForKey]->setText(KAccel::keyToString(ev->key(), true));
+         keyName[player][waitForKey]->setText(KKey(ev->key()).toString());
       }
       setButtons(-1,-1);
       ev->accept();
