@@ -2,8 +2,7 @@
 #include <qpixmap.h>
 #include <qtooltip.h>
 #include <klocale.h>
-#include <kstddirs.h>
-#include <qpixmap.h>
+#include <kstandarddirs.h>
 
 #include "defines.h"
 
