@@ -1,5 +1,6 @@
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
+#include <kaccel.h>
 #include <kkeydialog.h>
 #include <kstdaction.h>
 #include <kaction.h>
@@ -8,6 +9,7 @@
 #include "topwidget.h"
 #include "version.h"
 #include "defines.h"
+#include <kstatusbar.h>
 
 MyTopLevelWidget::MyTopLevelWidget(const char* name)
       :KMainWindow(0, name)
@@ -39,7 +41,7 @@ void MyTopLevelWidget::initActions( )
                                CTRL + Key_P, wview, SLOT( togglePause( ) ),
                                actionCollection( ), "pause" );
    newAct->setChecked( false );
-   ( void )new KAction( i18n( "Start" ), Key_Space, wview, SLOT( start( ) ),
+   KAction* gameStart = new KAction( i18n( "Start" ), Key_Space, wview, SLOT( start( ) ),
                         actionCollection( ), "game_start" );
    
    KStdAction::keyBindings( this, SLOT( keySetup( ) ), actionCollection( ) );
@@ -65,6 +67,9 @@ void MyTopLevelWidget::initActions( )
    KStdAction::saveOptions( this, SLOT( saveOptions( ) ),
                             actionCollection( ) );
 
+   KAccel* acc = new KAccel(this);
+   gameStart->plugAccel(acc);
+
    createGUI( "kspaceduelui.rc" );
 
 }
@@ -120,7 +125,7 @@ void MyTopLevelWidget::saveOptions()
 void MyTopLevelWidget::keySetup()
 {
    wview->pause();
-   KKeyDialog::configureKeys( actionCollection( ), "kspaceduelui.rc",
+   KKeyDialog::configureKeys( actionCollection( ), xmlFile(),
                               false, this );   
 }
 
