@@ -29,7 +29,7 @@
 #include <kiconloader.h>
 #include <kkeydialog.h>
 #include <kfiledialog.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kmenubar.h>
 #include <kconfig.h>
 #include <kio/netaccess.h>
@@ -37,24 +37,24 @@
 #include <kmessagebox.h>
 #include <kaction.h>
 #include <kstdaction.h>
-#include <kapp.h>
-
+#include <kstdgameaction.h>
+#include <kapplication.h>
+#include <kstatusbar.h>
+#include <kdebug.h>
 #define ID_STATUS_BASE 40
 
 #define MESSAGE_TIME 2000
-
 KTron::KTron(const char *name)
       : KMainWindow(0, name),
        skillAction(3)
 {
    playerPoints[0]=playerPoints[1]=0;
-
-   setMinimumSize(150,200);
    optionsDialog=0;
 
    tron=new Tron(this);
    connect(tron,SIGNAL(gameEnds(Player)),SLOT(changeStatus(Player)));
    setCentralWidget(tron);
+   tron->setMinimumSize(150,200);
 
    // create statusbar
    KStatusBar *statusbar= statusBar();
@@ -63,17 +63,17 @@ KTron::KTron(const char *name)
 
    accel=new KAccel(this,"Key Accel");
 
-   accel->insertItem(i18n("Player 1 Up"),"Pl1Up","R");
-   accel->insertItem(i18n("Player 1 Down"),"Pl1Down","F");
-   accel->insertItem(i18n("Player 1 Right"),"Pl1Right","G");
-   accel->insertItem(i18n("Player 1 Left"),"Pl1Left","D");
-   accel->insertItem(i18n("Player 1 Accelerator"),"Pl1Ac","A");
+   accel->insert("Pl1Up",    i18n("Player 1 Up"),          0, Key_R, 0, 0);
+   accel->insert("Pl1Down",  i18n("Player 1 Down"),        0, Key_F, 0, 0);
+   accel->insert("Pl1Right", i18n("Player 1 Right"),       0, Key_G, 0, 0);
+   accel->insert("Pl1Left",  i18n("Player 1 Left"),        0, Key_D, 0, 0);
+   accel->insert("Pl1Ac",    i18n("Player 1 Accelerator"), 0, Key_A, 0, 0);
 
-   accel->insertItem(i18n("Player 2 Up"),"Pl2Up","Up");
-   accel->insertItem(i18n("Player 2 Down"),"Pl2Down","Down");
-   accel->insertItem(i18n("Player 2 Right"),"Pl2Right","Right");
-   accel->insertItem(i18n("Player 2 Left"),"Pl2Left","Left");
-   accel->insertItem(i18n("Player 2 Accelerator"),"Pl2Ac","Plus");
+   accel->insert("Pl2Up",    i18n("Player 2 Up"),          0, Key_Up,    0, 0);
+   accel->insert("Pl2Down",  i18n("Player 2 Down"),        0, Key_Down,  0, 0);
+   accel->insert("Pl2Right", i18n("Player 2 Right"),       0, Key_Right, 0, 0);
+   accel->insert("Pl2Left",  i18n("Player 2 Left"),        0, Key_Left,  0, 0);
+   accel->insert("Pl2Ac",    i18n("Player 2 Accelerator"), 0, Key_Plus,  0, 0);
    accel->readSettings();
 
    tron->setAccel(accel);
@@ -82,12 +82,8 @@ KTron::KTron(const char *name)
    action=new KAction(i18n("&Pause/Continue"), Key_P, tron, SLOT(togglePause()),
           actionCollection(), "game_pause");
    action->plugAccel(accel);
-   action=new KAction(i18n("&New Game"), KStdAccel::openNew(), tron, SLOT(newGame()),
-          actionCollection(), "game_new");
-   action->plugAccel(accel);
-   action=new KAction(i18n("&Exit"), KStdAccel::quit(), this, SLOT(quit()),
-          actionCollection(), "game_quit");
-   action->plugAccel(accel);
+   KStdGameAction::gameNew( tron, SLOT( newGame() ), actionCollection() );
+   KStdGameAction::quit(this, SLOT( quit() ), actionCollection());
 
    /* options-menu  */
    new KToggleAction(i18n("Player &1"), 0 , this, SLOT(toggleComPl1()),
@@ -121,7 +117,7 @@ KTron::KTron(const char *name)
    selectAction->setItems(itemList);
    connect(selectAction, SIGNAL(activated(int)), this, SLOT(setVelocity(int)));
 
-   selectAction = new KSelectAction( i18n("&Drawing style"),  0
+   selectAction = new KSelectAction( i18n("&Drawing Style"),  0
                  , actionCollection(), "select_style");
    itemList.clear();
    itemList.append(i18n("&3D Line"));
@@ -150,10 +146,10 @@ KTron::KTron(const char *name)
    action=new KAction(i18n("Color Player &2..."), 0, this, SLOT(colorPl2()),
           actionCollection(), "color_player2");
    action->plugAccel(accel);
-   action=new KAction(i18n("&Backgroundcolor..."), 0, this, SLOT(colorBackground()),
+   action=new KAction(i18n("&Background Color..."), 0, this, SLOT(colorBackground()),
           actionCollection(), "color_background");
    action->plugAccel(accel);
-   action=new KAction(i18n("B&ackground image..."), 0, this, SLOT(chooseBgPix()),
+   action=new KAction(i18n("B&ackground Image..."), 0, this, SLOT(chooseBgPix()),
           actionCollection(), "background_image");
    action->plugAccel(accel);
 
@@ -213,7 +209,6 @@ KTron::KTron(const char *name)
    selectAction->setCurrentItem(velocity-1);
    tron->setVelocity(velocity);
 
-
    selectAction=(KSelectAction*)actionCollection()->action("select_style");
    TronStyle newStyle=(TronStyle)config->readNumEntry("Style",(int) OLine);
    // if the configfile is from a older than from KTron 0.5 than switch to
@@ -254,7 +249,7 @@ KTron::KTron(const char *name)
 
    tron->enableWinnerColor(config->readBoolEntry("ChangeWinnerColor",true));
    tron->setAcceleratorBlocked(config->readBoolEntry("AcceleratorBlocked",false));
-   tron->setOppositeDirCrashes(config->readBoolEntry("OppositeDirCrashes",true));
+   tron->setOppositeDirCrashes(config->readBoolEntry("OppositeDirCrashes",false));
 
    tron->restoreColors(config);
    readBackground(config);
@@ -264,7 +259,8 @@ KTron::KTron(const char *name)
 
 KTron::~KTron()
 {
-	saveSettings();
+   saveSettings();
+   delete tron;
 }
 
 
@@ -456,6 +452,7 @@ void KTron::quit()
 {
    saveSettings();
    kapp->quit();
+   delete this;
 }
 
 void KTron::toggleComPl1()
