@@ -1,65 +1,63 @@
-//#define EXPERIMENTAL
-
 /* -------------------------------------------------------------
    KDE Tuberling
    Play ground widget
    mailto:e.bischoff@noos.fr
  ------------------------------------------------------------- */
 
+#include <stdlib.h>
+
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kaudioplayer.h>
+#include <kprinter.h>
 
 #include <qfile.h>
 #include <qpainter.h>
 #include <qimage.h>
-#include <kprinter.h>
-
-#include <stdlib.h>
+#include <qcursor.h>
+#include <qdom.h>
 
 #include "playground.moc"
 #include "toplevel.h"
-#include "categories.h"
 
 #define XMARGIN 5
 #define YMARGIN 5
 
 // Constructor
-PlayGround::PlayGround( TopLevel *parent, const char *name )
+PlayGround::PlayGround( TopLevel *parent, const char *name, uint selectedGameboard )
     : QWidget( parent, name )
 {
   topLevel = parent;
 
-  objectsLayout = shapesLayout = 0;
+  textsLayout = objectsLayout = 0;
   textsList = soundsList = 0;
+  draggedCursor = 0;
 
   toDraw.setAutoDelete(true);
   history.setAutoDelete(true);
 
   setBackgroundColor(white);
 
-  if (!loadBitmaps())
-  {
-    KMessageBox::error(this,
-                       i18n("Fatal error:\n"
-                            "I could not load the pictures. I'll quit."));
-    exit(-1);
-  }
+  QDomDocument layoutsDocument;
+  bool ok = loadLayout(layoutsDocument);
+  if (ok) ok = registerPlayGrounds(layoutsDocument);
+  if (ok) ok = loadPlayGround(layoutsDocument, selectedGameboard);
+  if (!ok) loadFailure();
 
-  draggedCursor = 0;
   currentAction = 0;
-
   setupGeometry();
 }
 
 // Destructor
 PlayGround::~PlayGround()
 {
-  if (soundsList) delete soundsList;
-  if (textsList) delete textsList;
-  if (objectsLayout) delete objectsLayout;
-  if (shapesLayout) delete shapesLayout;
+  if (textsLayout) delete [] textsLayout;
+  if (objectsLayout) delete [] objectsLayout;
+
+  if (textsList) delete [] textsList;
+  if (soundsList) delete [] soundsList;
+
   if (draggedCursor) delete draggedCursor;
 }
 
@@ -71,6 +69,32 @@ void PlayGround::reset()
   currentAction = 0;
 }
 
+// Change the gameboard
+void PlayGround::change( uint selectedGameboard )
+{
+  QDomDocument layoutsDocument;
+  bool ok = loadLayout(layoutsDocument);
+  if (ok) ok = loadPlayGround(layoutsDocument, selectedGameboard);
+  if (!ok) loadFailure();
+
+  toDraw.clear();
+  history.clear();
+  currentAction = 0;
+
+  setupGeometry();
+
+  update();
+}
+
+// Report a load failure
+void PlayGround::loadFailure()
+{
+  KMessageBox::error(this,
+                     i18n("Fatal error:\n"
+                          "I could not load the pictures. I'll quit."));
+  exit(-1);
+}
+
 // Repaint all the editable area
 void PlayGround::repaintAll()
 {
@@ -151,13 +175,12 @@ bool PlayGround::saveAs(const QString & name)
   FILE *fp;
   const ToDraw *currentObject;
 
-  if (!(fp = fopen(QFile::encodeName(name), "w"))) return false;
+  if (!(fp = fopen((const char *) QFile::encodeName(name), "w"))) return false;
+
+  fprintf(fp, "%d\n", topLevel->getSelectedGameboard());
   for (currentObject = toDraw.first(); currentObject; currentObject = toDraw.next())
-    if (!currentObject->save(fp))
-    {
-      fclose(fp);
-      return false;
-    }
+    currentObject->save(fp);
+
   return !fclose(fp);
 }
 
@@ -165,7 +188,7 @@ bool PlayGround::saveAs(const QString & name)
 bool PlayGround::printPicture(KPrinter &printer) const
 {
   QPainter artist;
-  QPixmap picture(grabWindow());
+  QPixmap picture(getPicture());
 
   if (!artist.begin(&printer)) return false;
   artist.drawPixmap(QPoint(32, 32), picture);
@@ -173,100 +196,58 @@ bool PlayGround::printPicture(KPrinter &printer) const
   return true;
 }
 
+// Get a pixmap containing the current picture
+QPixmap PlayGround::getPicture() const
+{
+  QPixmap result(editableArea.size());
+  QPainter artist(&result);
+  QRect transEditableArea(editableArea);
+
+  transEditableArea.moveBy(-XMARGIN, -YMARGIN);
+  artist.translate(XMARGIN - editableArea.left(),
+                   YMARGIN - editableArea.top());
+  drawGameboard(artist, transEditableArea);
+  return result;
+}
+
 // Draw some text
-void PlayGround::drawText(QPainter &artist, QRect &area, int textNumber) const
+void PlayGround::drawText(QPainter &artist, QRect &area, QString &textId) const
 {
   QString label;
 
-  switch (textNumber)
-  {
-      case TEXT_EYES:
-        label = i18n("Eyes");
-        break;
-      case TEXT_EYEBROWS:
-        label = i18n("Eyesbrows");
-        break;
-      case TEXT_NOSES:
-        label = i18n("Noses");
-        break;
-      case TEXT_EARS:
-        label = i18n("Ears");
-        break;
-      case TEXT_MOUTHS:
-        label = i18n("Mouths");
-        break;
-      case TEXT_GOODIES:
-        label = i18n("Goodies");
-        break;
-      default:
-        return;
-  }
+  label=i18n(textId.latin1());
+
   artist.drawText(area, AlignCenter, label);
 }
 
 // Play some sound
-void PlayGround::playSound(int soundNumber) const
+void PlayGround::playSound(QString &soundId) const
 {
   QString soundName;
 
   if (!topLevel->isSoundEnabled()) return;
-  switch (soundNumber)
-  {
-    case SOUND_TUBERLING:
-        soundName = i18n("en/tuberling.wav");
-        break;
-    case SOUND_EYE:
-        soundName = i18n("en/eye.wav");
-        break;
-    case SOUND_EYEBROW:
-        soundName = i18n("en/eyebrow.wav");
-        break;
-    case SOUND_NOSE:
-        soundName = i18n("en/nose.wav");
-        break;
-    case SOUND_EAR:
-        soundName = i18n("en/ear.wav");
-        break;
-    case SOUND_MOUTH:
-        soundName = i18n("en/mouth.wav");
-        break;
-    case SOUND_HAT:
-        soundName = i18n("en/hat.wav");
-        break;
-    case SOUND_MOUSTACHE:
-        soundName = i18n("en/moustache.wav");
-        break;
-    case SOUND_CIGAR:
-        soundName = i18n("en/cigar.wav");
-        break;
-    case SOUND_TIE:
-        soundName = i18n("en/tie.wav");
-        break;
-    case SOUND_SUNGLASSES:
-        soundName = i18n("en/sunglasses.wav");
-        break;
-    case SOUND_SPECTACLES:
-        soundName = i18n("en/spectacles.wav");
-        break;
-    case SOUND_BOW:
-        soundName = i18n("en/bow.wav");
-        break;
-    case SOUND_EARRING:
-        soundName = i18n("en/earring.wav");
-        break;
-    case SOUND_BADGE:
-        soundName = i18n("en/badge.wav");
-        break;
-    case SOUND_WATCH:
-        soundName = i18n("en/watch.wav");
-        break;
-    default:
-        return;
-  }
+
+  soundName=i18n(soundId.latin1());
 
   KAudioPlayer::play(locate("data", "ktuberling/sounds/" + soundName));
 }
 
+// Paint the current picture to the given device
+void PlayGround::drawGameboard( QPainter &artist, const QRect &area ) const
+{
+  artist.drawPixmap(area.topLeft(), gameboard, area);
+
+  artist.setPen(white);
+  for (int text = 0; text < texts; text++)
+    drawText(artist, textsLayout[text], textsList[text]);
+
+  artist.setPen(black);
+  for (QPtrListIterator<ToDraw> currentObject(toDraw);
+       currentObject.current();
+       ++currentObject)
+    currentObject.current()->draw(artist, area, objectsLayout, &gameboard, &masks);
+}
+
 // Painting event
 void PlayGround::paintEvent( QPaintEvent *event )
 {
@@ -276,23 +257,13 @@ void PlayGround::paintEvent( QPaintEvent *event )
   QRect area(position, QSize(event->rect().size()));
   QPixmap cache(gameboard.size());
   QPainter artist(&cache);
-  const ToDraw *currentObject;
-  int text;
 
   if (destination.x() < XMARGIN) destination.setX(XMARGIN);
   if (destination.y() < YMARGIN) destination.setY(YMARGIN);
   area = QRect(0, 0, gameboard.width(), gameboard.height()).intersect(area);
   if (area.isEmpty()) return;
 
-  artist.drawPixmap(area.topLeft(), gameboard, area);
-
-  artist.setPen(color0);
-  for (text = 0; text < texts; text++)
-    drawText(artist, textsLayout[text], textsList[text]);
-  artist.setPen(color1);
-
-  for (currentObject = toDraw.first(); currentObject; currentObject = toDraw.next())
-    currentObject->draw(artist, area, objectsLayout, shapesLayout, &gameboard, &masks);
+  drawGameboard(artist, area);
 
   bitBlt(this, destination, &cache, area, Qt::CopyROP);
 }
@@ -308,9 +279,9 @@ void PlayGround::mousePressEvent( QMouseEvent *event )
 
   int draggedNumber = draggedObject.getNumber();
   QPixmap object(objectsLayout[draggedNumber].size());
-  QBitmap shape(shapesLayout[draggedNumber].size());
+  QBitmap shape(objectsLayout[draggedNumber].size());
   bitBlt(&object, QPoint(0, 0), &gameboard, objectsLayout[draggedNumber], Qt::CopyROP);
-  bitBlt(&shape, QPoint(0, 0), &masks, shapesLayout[draggedNumber], Qt::CopyROP);
+  bitBlt(&shape, QPoint(0, 0), &masks, objectsLayout[draggedNumber], Qt::CopyROP);
   object.setMask(shape);
 
   if (!(draggedCursor = new QCursor
@@ -378,94 +349,189 @@ void PlayGround::mouseReleaseEvent( QMouseEvent *event )
 
 }
 
-// Load background and draggable objects masks
-bool PlayGround::loadBitmaps()
+// Load the layouts file
+bool PlayGround::loadLayout(QDomDocument &layoutDocument)
 {
-  FILE *layoutFile;
-  char comment[512];
-  int editableLeft, editableTop, editableRight, editableBottom;
-  int textLeft, textTop, textRight, textBottom;
-  int objectLeft, objectTop, objectRight, objectBottom;
-  int shapeLeft, shapeTop, shapeRight, shapeBottom;
-  QRect *text, *object, *shape;
-  int *label, *sound;
+  QFile layoutFile(QFile::encodeName(locate("data", "ktuberling/pics/layout.xml")));
+  if (!layoutFile.open(IO_ReadOnly))
+     return false;
 
-#ifdef EXPERIMENTAL
-  if (!gameboard.load("pics/gameboard.png"))
-#else
-  if (!gameboard.load(locate("data", "ktuberling/pics/gameboard.xpm")))
-#endif
-  	  return false;
+  if (!layoutDocument.setContent(&layoutFile))
+  {
+     layoutFile.close();
+     return false;
+  }
+  layoutFile.close();
 
-#ifdef EXPERIMENTAL
-  if (!masks.load("pics/masks.png"))
-#else
-  if (!masks.load(locate("data", "ktuberling/pics/masks.xpm")))
-#endif
-        return false;
+  return true;
+}
 
-  if (!(layoutFile = fopen(QFile::encodeName(locate("data", "ktuberling/pics/layout.txt")), "r")))
-        return false;
+// Register the various playgrounds
+bool PlayGround::registerPlayGrounds(QDomDocument &layoutDocument)
+{
+  QDomNodeList playGroundsList, menuItemsList, labelsList;
+  QDomElement playGroundElement, menuItemElement, labelElement;
+  QDomAttr actionAttribute;
+
+  playGroundsList = layoutDocument.elementsByTagName("playground");
+  if (playGroundsList.count() < 1)
+    return false;
+
+  for (uint i = 0; i < playGroundsList.count(); i++)
+  {
+    playGroundElement = (const QDomElement &) playGroundsList.item(i).toElement();
+
+    menuItemsList = playGroundElement.elementsByTagName("menuitem");
+    if (menuItemsList.count() != 1)
+      return false;
+
+    menuItemElement = (const QDomElement &) menuItemsList.item(0).toElement();
+
+    labelsList = menuItemElement.elementsByTagName("label");
+    if (labelsList.count() != 1)
+      return false;
+
+    labelElement = (const QDomElement &) labelsList.item(0).toElement();
+    actionAttribute = menuItemElement.attributeNode("action");
+    topLevel->registerGameboard(labelElement.text(), actionAttribute.value().latin1()); 
+  }
+ 
+  return true;
+}
+
+// Load background and draggable objects masks
+bool PlayGround::loadPlayGround(QDomDocument &layoutDocument, uint toLoad)
+{
+  QDomNodeList playGroundsList,
+               editableAreasList, categoriesList, objectsList,
+               gameAreasList, maskAreasList, soundNamesList, labelsList;
+  QDomElement playGroundElement,
+              editableAreaElement, categoryElement, objectElement,
+              gameAreaElement, maskAreaElement, soundNameElement, labelElement;
+  QDomAttr gameboardAttribute, masksAttribute,
+           leftAttribute, topAttribute, rightAttribute, bottomAttribute;
+
+  playGroundsList = layoutDocument.elementsByTagName("playground");
+  if (toLoad >= playGroundsList.count())
+    return false;
+
+  playGroundElement = (const QDomElement &) playGroundsList.item(toLoad).toElement();
+
+  gameboardAttribute = playGroundElement.attributeNode("gameboard");
+  if (!gameboard.load(locate("data", "ktuberling/pics/" + gameboardAttribute.value())))
+    return false;
+
+  masksAttribute = playGroundElement.attributeNode("masks");
+  if (!masks.load(locate("data", "ktuberling/pics/" + masksAttribute.value())))
+    return false;
+
+  editableAreasList = playGroundElement.elementsByTagName("editablearea");
+  if (editableAreasList.count() != 1)
+    return false;
+
+  editableAreaElement = (const QDomElement &) editableAreasList.item(0).toElement();
+
+  gameAreasList = editableAreaElement.elementsByTagName("position");
+  if (gameAreasList.count() != 1)
+    return false;
+
+  gameAreaElement = (const QDomElement &) gameAreasList.item(0).toElement();
+  leftAttribute = gameAreaElement.attributeNode("left");
+  topAttribute = gameAreaElement.attributeNode("top");
+  rightAttribute = gameAreaElement.attributeNode("right");
+  bottomAttribute = gameAreaElement.attributeNode("bottom");
 
-  if (fscanf(layoutFile, "%d %d %d %d %d",
-             &editableLeft, &editableTop, &editableRight, &editableBottom,
-             &editableSound) != 5) { fclose(layoutFile); return false; }
-  if (!fgets(comment, sizeof(comment), layoutFile))
-        { fclose(layoutFile); return false; }
   editableArea.setCoords
-        (XMARGIN + editableLeft,
-         YMARGIN + editableTop,
-         XMARGIN + editableRight,
-         YMARGIN + editableBottom);
+        (XMARGIN + leftAttribute.value().toInt(),
+         YMARGIN + topAttribute.value().toInt(),
+         XMARGIN + rightAttribute.value().toInt(),
+         YMARGIN + bottomAttribute.value().toInt());
 
-  if (fscanf(layoutFile, "%d", &texts) != 1)
-        { fclose(layoutFile); return false; }
-  if (!fgets(comment, sizeof(comment), layoutFile))
-        { fclose(layoutFile); return false; }
+  soundNamesList = editableAreaElement.elementsByTagName("sound");
+  if (soundNamesList.count() != 1)
+    return false;
+
+  soundNameElement = (const QDomElement &) soundNamesList.item(0).toElement();
+
+  editableSound = soundNameElement.text();
+
+  categoriesList = playGroundElement.elementsByTagName("category");
+  texts = categoriesList.count();
   if (texts < 1)
-        { fclose(layoutFile); return false; }
+    return false;
 
-  if (!(textsLayout = new QRect[texts])) { fclose(layoutFile); return false; }
-  if (!(textsList = new int[texts])) { fclose(layoutFile); return false; }
-  for (text = textsLayout, label = textsList;
-       text < textsLayout + texts;
-       text++, label++)
+  if (!(textsLayout = new QRect[texts]))
+    return false;
+  if (!(textsList = new QString[texts]))
+    return false;
+
+  for (uint text = 0; text < texts; text++)
   {
-    if (fscanf(layoutFile,
-               "%d %d %d %d %d",
-               &textLeft, &textTop, &textRight, &textBottom,
-               label) != 5) { fclose(layoutFile); return false; }
-    if (!fgets(comment, sizeof(comment), layoutFile))
-                 { fclose(layoutFile); return false; }
-    text->setCoords(textLeft, textTop, textRight, textBottom);
+    categoryElement = (const QDomElement &) categoriesList.item(text).toElement();
+
+    gameAreasList = categoryElement.elementsByTagName("position");
+    if (gameAreasList.count() != 1)
+      return false;
+
+    gameAreaElement = (const QDomElement &) gameAreasList.item(0).toElement();
+    leftAttribute = gameAreaElement.attributeNode("left");
+    topAttribute = gameAreaElement.attributeNode("top");
+    rightAttribute = gameAreaElement.attributeNode("right");
+    bottomAttribute = gameAreaElement.attributeNode("bottom");
+
+    textsLayout[text].setCoords
+	    (leftAttribute.value().toInt(),
+	     topAttribute.value().toInt(),
+	     rightAttribute.value().toInt(),
+	     bottomAttribute.value().toInt());
+
+    labelsList = categoryElement.elementsByTagName("label");
+    if (labelsList.count() != 1)
+      return false;
+
+    labelElement = (const QDomElement &) labelsList.item(0).toElement();
+
+    textsList[text] = labelElement.text();
   }
 
-  if (fscanf(layoutFile, "%d", &decorations) != 1)
-        { fclose(layoutFile); return false; }
-  if (!fgets(comment, sizeof(comment), layoutFile))
-        { fclose(layoutFile); return false; }
+  objectsList = playGroundElement.elementsByTagName("object");
+  decorations = objectsList.count();
   if (decorations < 1)
-        { fclose(layoutFile); return false; }
+    return false;
 
-  if (!(objectsLayout = new QRect[decorations])) { fclose(layoutFile); return false; }
-  if (!(shapesLayout = new QRect[decorations])) { fclose(layoutFile); return false; }
-  if (!(soundsList = new int[decorations])) { fclose(layoutFile); return false; }
-  for (object = objectsLayout, shape = shapesLayout, sound = soundsList;
-       object < objectsLayout + decorations;
-       object++, shape++, sound++)
+  if (!(objectsLayout = new QRect[decorations]))
+    return false;
+  if (!(soundsList = new QString[decorations]))
+    return false;
+
+  for (uint decoration = 0; decoration < decorations; decoration++)
   {
-    if (fscanf(layoutFile,
-               "%d %d %d %d  %d %d %d %d  %d",
-               &objectLeft, &objectTop, &objectRight, &objectBottom,
-               &shapeLeft, &shapeTop, &shapeRight, &shapeBottom,
-               sound) != 9)
-                { fclose(layoutFile); return false; }
-    if (!fgets(comment, sizeof(comment), layoutFile))
-                { fclose(layoutFile); return false; }
-    object->setCoords(objectLeft, objectTop, objectRight, objectBottom);
-    shape->setCoords(shapeLeft, shapeTop, shapeRight, shapeBottom);
+    objectElement = (const QDomElement &) objectsList.item(decoration).toElement();
+
+    gameAreasList = objectElement.elementsByTagName("position");
+    if (gameAreasList.count() != 1)
+      return false;
+
+    gameAreaElement = (const QDomElement &) gameAreasList.item(0).toElement();
+    leftAttribute = gameAreaElement.attributeNode("left");
+    topAttribute = gameAreaElement.attributeNode("top");
+    rightAttribute = gameAreaElement.attributeNode("right");
+    bottomAttribute = gameAreaElement.attributeNode("bottom");
+
+    objectsLayout[decoration].setCoords
+	    (leftAttribute.value().toInt(),
+	     topAttribute.value().toInt(),
+	     rightAttribute.value().toInt(),
+	     bottomAttribute.value().toInt());
+
+    soundNamesList = objectElement.elementsByTagName("sound");
+    if (soundNamesList.count() != 1)
+      return false;
+
+    soundNameElement = (const QDomElement &) soundNamesList.item(0).toElement();
+
+    soundsList[decoration] = soundNameElement.text();
   }
-  if (fclose(layoutFile)) return false;
 
   return true;
 }
@@ -511,10 +577,10 @@ bool PlayGround::zone(QPoint &position)
     draggedObject = *currentObject;
     draggedNumber = draggedObject.getNumber();
 
-    QBitmap shape(shapesLayout[draggedNumber].size());
+    QBitmap shape(objectsLayout[draggedNumber].size());
     QPoint relative(position.x() - toUpdate.x(),
                     position.y() - toUpdate.y());
-    bitBlt(&shape, QPoint(0, 0), &masks, shapesLayout[draggedNumber], Qt::CopyROP);
+    bitBlt(&shape, QPoint(0, 0), &masks, objectsLayout[draggedNumber], Qt::CopyROP);
     if (!shape.convertToImage().pixelIndex(relative.x(), relative.y())) continue;
 
     toDraw.remove(draggedZOrder);
@@ -542,6 +608,16 @@ bool PlayGround::loadFrom(const QString & name)
   Action *newAction;
 
   if (!(fp = fopen(QFile::encodeName(name), "r"))) return false;
+
+  uint newGameboard;
+  int nitems = fscanf(fp, "%d\n", &newGameboard);
+  if (nitems == EOF)
+  {
+    fclose(fp);
+    return false;
+  }
+  change(newGameboard);
+
   for (;;)
   {
     if (!readObject.load(fp, decorations, eof))
