@@ -4,26 +4,29 @@
    mailto:e.bischoff@noos.fr
  ------------------------------------------------------------- */
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmessagebox.h>
 #include <ktoolbarbutton.h>
 #include <kmenubar.h>
 #include <kstdaccel.h>
 #include <kfiledialog.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kconfig.h>
 #include <kio/netaccess.h>
+#include <kaction.h>
+#include <kstdaction.h>
+#include <kstdgameaction.h>
 
-#include <qprinter.h>
+#include <kprinter.h>
 #include <qprintdialog.h>
 #include <qclipboard.h>
 
 #include <stdlib.h>
+#include <unistd.h>
 
-#include "toplevel.h"
+#include "toplevel.moc"
 #include "playground.h"
-#include "categories.h"
 
 // Constructor
 TopLevel::TopLevel()
@@ -31,11 +34,12 @@ TopLevel::TopLevel()
 {
   readOptions();
 
-  playGround = new PlayGround( this, "playground" );
-  setCentralWidget( playGround );
+  gameboards = 0;
+  playGround = new PlayGround(this, "playground", selectedGameboard);
 
-  setupMenuBar();
-  setupToolBar();
+  setCentralWidget(playGround);
+
+  setupKAction();
 }
 
 // Destructor
@@ -46,15 +50,60 @@ TopLevel::~TopLevel()
 // Enable or disable "undo" button and menu item
 void TopLevel::enableUndo(bool enable) const
 {
-  editMenu->setItemEnabled(undoID, enable);
-  toolbar->setItemEnabled(ID_UNDO, enable);
+  actionCollection()->action(KStdAction::stdName(KStdAction::Undo))->setEnabled(enable);
 }
 
 // Enable or disable "redo" button and menu item
 void TopLevel::enableRedo(bool enable) const
 {
-  editMenu->setItemEnabled(redoID, enable);
-  toolbar->setItemEnabled(ID_REDO, enable);
+  actionCollection()->action(KStdAction::stdName(KStdAction::Redo))->setEnabled(enable);
+}
+
+// Register an available gameboard
+void TopLevel::registerGameboard(const QString &menuItem, const char *actionId)
+{
+  KToggleAction *t;
+
+  switch (gameboards)
+  {
+  	case 0: t = new KToggleAction(i18n(menuItem.latin1()), 0, this, SLOT(optionsGameboard0()), actionCollection(), actionId);
+		break;
+  	case 1: t = new KToggleAction(i18n(menuItem.latin1()), 0, this, SLOT(optionsGameboard1()), actionCollection(), actionId);
+		break;
+  	case 2: t = new KToggleAction(i18n(menuItem.latin1()), 0, this, SLOT(optionsGameboard2()), actionCollection(), actionId);
+		break;
+  	case 3: t = new KToggleAction(i18n(menuItem.latin1()), 0, this, SLOT(optionsGameboard3()), actionCollection(), actionId);
+		break;
+  	case 4: t = new KToggleAction(i18n(menuItem.latin1()), 0, this, SLOT(optionsGameboard4()), actionCollection(), actionId);
+		break;
+  	case 5: t = new KToggleAction(i18n(menuItem.latin1()), 0, this, SLOT(optionsGameboard5()), actionCollection(), actionId);
+		break;
+  	case 6: t = new KToggleAction(i18n(menuItem.latin1()), 0, this, SLOT(optionsGameboard6()), actionCollection(), actionId);
+		break;
+  	case 7: t = new KToggleAction(i18n(menuItem.latin1()), 0, this, SLOT(optionsGameboard7()), actionCollection(), actionId);
+		break;
+  }
+  if (gameboards == selectedGameboard) t->setChecked(true);
+  gameboardActions[gameboards] = actionId;
+  gameboards++;
+}
+
+// Switch to another gameboard
+void TopLevel::changeGameboard(uint newGameboard)
+{
+  // Do not accept to switch to same gameboard
+  if (newGameboard == selectedGameboard)
+    return;
+
+  // Unselect preceeding gameboard
+  ((KToggleAction*) actionCollection()->action(gameboardActions[selectedGameboard].latin1()))->setChecked(false);
+
+  // Change gameboard in the remembered options
+  selectedGameboard = newGameboard;
+  writeOptions();
+
+  // Change gameboard effectively
+  playGround->change(newGameboard);
 }
 
 // Read options from preferences file
@@ -68,6 +117,11 @@ void TopLevel::readOptions()
   config->setGroup("General");
   option = config->readEntry("Sound", "on");
   soundEnabled = option.find("on") == 0;
+
+  option = config->readEntry("GameboardNumber", "0");
+  selectedGameboard = option.toInt();
+  if (selectedGameboard < 0) selectedGameboard = 0;
+  if (selectedGameboard > 7) selectedGameboard = 7;
 }
 
 // Write options to preferences file
@@ -79,88 +133,35 @@ void TopLevel::writeOptions()
 
   config->setGroup("General");
   config->writeEntry("Sound", soundEnabled? "on": "off");
+
+  config->writeEntry("GameboardNumber", selectedGameboard);
+
   config->sync();
 }
 
-// Menubar initialization
-void TopLevel::setupMenuBar()
+// KAction initialization (aka menubar + toolbar init)
+void TopLevel::setupKAction()
 {
-  menubar = menuBar();
+//Game
+  KStdGameAction::gameNew(this, SLOT(fileNew()), actionCollection());
+  KStdGameAction::load(this, SLOT(fileOpen()), actionCollection());
+  KStdGameAction::save(this, SLOT(fileSave()), actionCollection());
+  KStdGameAction::print(this, SLOT(filePrint()), actionCollection());
+  KStdGameAction::quit(kapp, SLOT(quit()), actionCollection());
+  (void) new KAction(i18n("Save &as Picture..."), 0, this, SLOT(filePicture()), actionCollection(), "game_save_picture");
 
-  fileMenu = new QPopupMenu( this );
-  editMenu = new QPopupMenu( this );
-  optionsMenu = new QPopupMenu( this );
+//Edit
+  KStdAction::copy(this, SLOT(editCopy()), actionCollection());
+  KStdAction::undo(this, SLOT(editUndo()), actionCollection());
+  KStdAction::redo(this, SLOT(editRedo()), actionCollection());
+  enableUndo(false);
+  enableRedo(false);
+  
+//Settings
+  KToggleAction* t = new KToggleAction(i18n("&Sound"), 0, this, SLOT(optionsSound()), actionCollection(), "options_sound");
+  t->setChecked(soundEnabled);
 
-  newID = fileMenu->insertItem(SmallIcon("filenew"), i18n("&New"));
-  fileMenu->connectItem(newID, this, SLOT(fileNew()));
-  fileMenu->setAccel(KStdAccel::key(KStdAccel::New), newID);
-
-  openID = fileMenu->insertItem(SmallIcon("fileopen"), i18n("&Open..."));
-  fileMenu->connectItem(openID, this, SLOT(fileOpen()));
-  fileMenu->setAccel(KStdAccel::key(KStdAccel::Open), openID);
-
-  saveID = fileMenu->insertItem(SmallIcon("filesave"), i18n("&Save..."));
-  fileMenu->connectItem(saveID, this, SLOT(fileSave()));
-  fileMenu->setAccel(KStdAccel::key(KStdAccel::Save), saveID);
-
-  pictureID = fileMenu->insertItem(i18n("Save &as picture..."));
-  fileMenu->connectItem(pictureID, this, SLOT(filePicture()));
-  fileMenu->insertSeparator();
-
-  printID = fileMenu->insertItem(SmallIcon("fileprint"), i18n("&Print"));
-  fileMenu->connectItem(printID, this, SLOT(filePrint()));
-  fileMenu->setAccel(KStdAccel::key(KStdAccel::Print), printID);
-  fileMenu->insertSeparator();
-
-  quitID = fileMenu->insertItem(SmallIcon("exit"), i18n("&Quit"));
-  fileMenu->connectItem(quitID, kapp, SLOT(quit()));
-  fileMenu->setAccel(KStdAccel::key(KStdAccel::Quit), quitID);
-
-  copyID = editMenu->insertItem(SmallIcon("editcopy"), i18n("&Copy"));
-  editMenu->connectItem(copyID, this, SLOT(editCopy()));
-  editMenu->setAccel(KStdAccel::key(KStdAccel::Copy), copyID);
-  editMenu->insertSeparator();
-
-  undoID = editMenu->insertItem(SmallIcon("undo"), i18n("&Undo"));
-  editMenu->setItemEnabled(undoID, false);
-  editMenu->connectItem(undoID, this, SLOT(editUndo()));
-  editMenu->setAccel(KStdAccel::key(KStdAccel::Undo), undoID);
-
-
-  redoID = editMenu->insertItem(SmallIcon("redo"), i18n("&Redo"));
-  editMenu->setItemEnabled(redoID, false);
-  editMenu->connectItem(redoID, this, SLOT(editRedo()));
-  editMenu->setAccel(KStdAccel::key(KStdAccel::Redo), redoID);
-
-  soundID = optionsMenu->insertItem(i18n("&Sound"));
-  optionsMenu->setItemChecked(soundID, soundEnabled);
-  optionsMenu->connectItem(soundID, this, SLOT(optionsSound()));
-
-  QString about = i18n("A program by Eric Bischoff <e.bischoff@noos.fr>\n"
-                       "and John Calhoun.\n\n"
-                       "This program is dedicated to my daughter Sunniva.");
-
-  menubar->insertItem(i18n("&File"), fileMenu);
-  menubar->insertItem(i18n("&Edit"), editMenu);
-  menubar->insertItem(i18n("&Options"), optionsMenu);
-  menubar->insertSeparator(-1);
-  menubar->insertItem(i18n("&Help"), helpMenu(about));
-
-}
-
-// Toolbar initialization
-void TopLevel::setupToolBar()
-{
-  toolbar = toolBar();
-
-  toolbar->insertButton("filenew", ID_NEW, SIGNAL(pressed()), this, SLOT(fileNew()), true, i18n("New"));
-  toolbar->insertButton("fileopen", ID_OPEN, SIGNAL(pressed()), this, SLOT(fileOpen()), true, i18n("Open"));
-  toolbar->insertButton("filesave", ID_SAVE, SIGNAL(pressed()), this, SLOT(fileSave()), true, i18n("Save"));
-  toolbar->insertButton("fileprint", ID_PRINT, SIGNAL(pressed()), this, SLOT(filePrint()), true, i18n("Print"));
-  toolbar->insertSeparator();
-
-  toolbar->insertButton("undo", ID_UNDO, SIGNAL(pressed()), this, SLOT(editUndo()), false, i18n("Undo"));
-  toolbar->insertButton("redo", ID_REDO, SIGNAL(pressed()), this, SLOT(editRedo()), false, i18n("Redo"));
+  createGUI("ktuberlingui.rc");
 }
 
 // Reset gameboard
@@ -184,8 +185,6 @@ void TopLevel::fileOpen()
 
   KURL url = KFileDialog::getOpenURL(dir, "*.tuberling");
 
-  toolbar->getButton(ID_OPEN)->setDown(false);
-
   if (url.isEmpty())
     return;
 
@@ -207,19 +206,13 @@ void TopLevel::fileOpen()
 // Save gameboard
 void TopLevel::fileSave()
 {
-  QString name;
-
-  QString dir = locate("data", "ktuberling/museum/miss.tuberling");
-  dir.truncate(dir.find('/') + 1);
-
-  KURL url = KFileDialog::getSaveURL(dir, "*.tuberling");
-
-  toolbar->getButton(ID_SAVE)->setDown(false);
+  KURL url = KFileDialog::getSaveURL
+                (getenv("HOME"),
+		 "*.tuberling");
 
   if (url.isEmpty())
     return;
 
-
   if( !url.isLocalFile() )
   {
     KMessageBox::sorry(this,
@@ -228,14 +221,23 @@ void TopLevel::fileSave()
     return;
   }
 
-  if( !playGround->saveAs( url.path() ) )
+  QString name = url.path();
+  int suffix;
+
+  suffix = name.findRev('.');
+  if (suffix == -1)
+  {
+    name += ".tuberling";
+  }
+
+  if( !playGround->saveAs( name ) )
     KMessageBox::error(this, i18n("Could not save file."));
 }
 
 // Save gameboard as picture
 void TopLevel::filePicture()
 {
-  QPixmap picture(playGround->grabWindow());
+  QPixmap picture(playGround->getPicture());
 
   KURL url = KFileDialog::getSaveURL
                 (getenv("HOME"),
@@ -244,12 +246,15 @@ void TopLevel::filePicture()
                         "*.png|Next generation pictures (*.png)\n"
                         "*.bmp|Windows bitmaps (*.bmp)\n"
                         "*|All picture formats"));
+
   if( url.isEmpty() )
     return;
 
   if( !url.isLocalFile() )
   {
-    KMessageBox::sorry( 0L, i18n( "Only saving to local files supported yet." ) );
+    KMessageBox::sorry(this,
+                       i18n("Only saving to local files currently "
+                            "supported."));
     return;
   }
 
@@ -284,11 +289,10 @@ void TopLevel::filePicture()
 // Save gameboard as picture
 void TopLevel::filePrint()
 {
-  QPrinter printer;
+  KPrinter printer;
   bool ok;
 
-  ok = QPrintDialog::getPrinterSetup(&printer);
-  toolbar->getButton(ID_PRINT)->setDown(false);
+  ok = printer.setup(this);
   if (!ok) return;
   playGround->repaint(true);
   if (!playGround->printPicture(printer))
@@ -303,7 +307,7 @@ void TopLevel::filePrint()
 void TopLevel::editCopy()
 {
   QClipboard *clipboard = QApplication::clipboard();
-  QPixmap picture(playGround->grabWindow());
+  QPixmap picture(playGround->getPicture());
 
   clipboard->setPixmap(picture);
 }
@@ -312,7 +316,6 @@ void TopLevel::editCopy()
 void TopLevel::editUndo()
 {
   if (playGround->isFirstAction()) return;
-  toolbar->getButton(ID_UNDO)->setDown(false);
 
   if (!playGround->undo()) return;
 
@@ -326,7 +329,6 @@ void TopLevel::editUndo()
 void TopLevel::editRedo()
 {
   if (playGround->isLastAction()) return;
-  toolbar->getButton(ID_REDO)->setDown(false);
 
   if (!playGround->redo()) return;
 
@@ -340,6 +342,55 @@ void TopLevel::editRedo()
 void TopLevel::optionsSound()
 {
   soundEnabled = !soundEnabled;
-  optionsMenu->setItemChecked( soundID, soundEnabled);
+  ((KToggleAction*) actionCollection()->action("options_sound"))->setChecked(soundEnabled);
+
   writeOptions();
 }
+
+// Switch to gameboard #0
+void TopLevel::optionsGameboard0()
+{
+  changeGameboard(0);
+}
+
+// Switch to gameboard #1
+void TopLevel::optionsGameboard1()
+{
+  changeGameboard(1);
+}
+
+// Switch to gameboard #2
+void TopLevel::optionsGameboard2()
+{
+  changeGameboard(2);
+}
+
+// Switch to gameboard #3
+void TopLevel::optionsGameboard3()
+{
+  changeGameboard(3);
+}
+
+// Switch to gameboard #4
+void TopLevel::optionsGameboard4()
+{
+  changeGameboard(4);
+}
+
+// Switch to gameboard #5
+void TopLevel::optionsGameboard5()
+{
+  changeGameboard(5);
+}
+
+// Switch to gameboard #6
+void TopLevel::optionsGameboard6()
+{
+  changeGameboard(6);
+}
+
+// Switch to gameboard #7
+void TopLevel::optionsGameboard7()
+{
+  changeGameboard(7);
+}
