@@ -16,10 +16,11 @@
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
 */
+
 #include <kstdgameaction.h>
-#include <kstdaccel.h>
 #include <klocale.h>
 #include <kaction.h>
+#include <kstdaccel.h>
 
 KStdGameAction::KStdGameAction()
 {
@@ -30,7 +31,7 @@ KStdGameAction::~KStdGameAction()
 }
 
 KAction *KStdGameAction::action(StdGameAction act_enum, const QObject *recvr,
-                            const char *slot, QObject *parent, const char *name )
+                            const char *slot, KActionCollection *parent, const char *name )
 {
     KAction *act;
     switch (act_enum)
@@ -41,6 +42,9 @@ KAction *KStdGameAction::action(StdGameAction act_enum, const QObject *recvr,
     case Load:
         act = load(recvr, slot, parent, name);
         break;
+    case LoadRecent:
+        act = loadRecent(recvr, slot, parent, name);
+        break;
     case Save:
         act = save(recvr, slot, parent, name);
         break;
@@ -74,6 +78,9 @@ KAction *KStdGameAction::action(StdGameAction act_enum, const QObject *recvr,
     case EndTurn:
         act = endTurn(recvr, slot, parent, name);
         break;
+    case Roll:
+        act = roll(recvr, slot, parent, name);
+        break;
     case Carddecks:
         act = carddecks(recvr, slot, parent, name);
         break;
@@ -96,6 +103,9 @@ const char* KStdGameAction::stdName(StdGameAction act_enum)
     case Load:
         ret = "game_load";
         break;
+    case LoadRecent:
+        ret = "game_load_recent";
+        break;
     case Save:
         ret = "game_save";
         break;
@@ -126,6 +136,9 @@ const char* KStdGameAction::stdName(StdGameAction act_enum)
     case Redo:
         ret = "move_redo";
 	break;
+    case Roll:
+        ret = "move_roll";
+	break;
     case EndTurn:
         ret = "move_endturn";
 	break;
@@ -141,23 +154,31 @@ const char* KStdGameAction::stdName(StdGameAction act_enum)
 }
 
 KAction *KStdGameAction::gameNew(const QObject *recvr, const char *slot,
-                             QObject *parent, const char *name )
+                             KActionCollection *parent, const char *name )
 {
-    return new KAction(i18n("&New"), "filenew",
+    return new KAction(i18n("new game", "&New"), "filenew",
                        KStdAccel::key(KStdAccel::New), recvr, slot, parent,
                        name ? name : stdName(New));
 }
 
 KAction *KStdGameAction::load(const QObject *recvr, const char *slot,
-                                                  QObject *parent, const char *name )
+                                                  KActionCollection *parent, const char *name )
 {
     return new KAction(i18n("&Load..."), "fileopen",
                        KStdAccel::key(KStdAccel::Open), recvr, slot, parent,
                        name ? name : stdName(Load));
 }
 
+KRecentFilesAction *KStdGameAction::loadRecent(const QObject *recvr, const char *slot,
+                                                  KActionCollection *parent, const char *name )
+{
+    return new KRecentFilesAction(i18n("Load &Recent"), 0,
+                       KStdAccel::AccelNone, recvr, slot, parent,
+                       name ? name : stdName(LoadRecent));
+}
+
 KAction *KStdGameAction::save(const QObject *recvr, const char *slot,
-                                                  QObject *parent, const char *name )
+                                                  KActionCollection *parent, const char *name )
 {
     return new KAction(i18n("&Save"), "filesave",
                        KStdAccel::key(KStdAccel::Save), recvr, slot, parent,
@@ -165,30 +186,30 @@ KAction *KStdGameAction::save(const QObject *recvr, const char *slot,
 }
 
 KAction *KStdGameAction::saveAs(const QObject *recvr, const char *slot,
-                                                        QObject *parent, const char *name )
+                                                        KActionCollection *parent, const char *name )
 {
     return new KAction(i18n("Save &As..."), 0, recvr, slot, parent,
                        name ? name : stdName(SaveAs));
 }
 
 KToggleAction *KStdGameAction::pause(const QObject *recvr, const char *slot,
-                                                  QObject *parent, const char *name )
+                                                  KActionCollection *parent, const char *name )
 {
-    return new KToggleAction(i18n("Pa&use"), "player_pause", 0, recvr, slot, parent,
+    return new KToggleAction(i18n("Pa&use"), "player_pause", Qt::Key_P, recvr, slot, parent,
                        name ? name : stdName(Pause));
 }
 
 KAction *KStdGameAction::highscores(const QObject *recvr, const char *slot,
-                                                        QObject *parent, const char *name )
+                                                        KActionCollection *parent, const char *name )
 {
 //hmm perhaps we need a KStdGameAccel one day? currently this entry is hard
 //coded...
-    return new KAction(i18n("Show Highscores"), KAccel::stringToKey("CTRL+H"), recvr, slot, parent,
+    return new KAction(i18n("Show Highscores"), Qt::CTRL+Qt::Key_H, recvr, slot, parent,
                        name ? name : stdName(Highscores));
 }
 
 KAction *KStdGameAction::print(const QObject *recvr, const char *slot,
-                                                   QObject *parent, const char *name )
+                                                   KActionCollection *parent, const char *name )
 {
     return new KAction(i18n("&Print..."), "fileprint",
                        KStdAccel::key(KStdAccel::Print), recvr, slot, parent,
@@ -196,15 +217,15 @@ KAction *KStdGameAction::print(const QObject *recvr, const char *slot,
 }
 
 KAction *KStdGameAction::end(const QObject *recvr, const char *slot,
-                                                   QObject *parent, const char *name )
+                                                   KActionCollection *parent, const char *name )
 {
-    return new KAction(i18n("&End game"), "fileclose",
+    return new KAction(i18n("&End Game"), "fileclose",
                        KStdAccel::key(KStdAccel::End), recvr, slot, parent,
                        name ? name : stdName(End));
 }
 
 KAction *KStdGameAction::quit(const QObject *recvr, const char *slot,
-                                                  QObject *parent, const char *name )
+                                                  KActionCollection *parent, const char *name )
 {
     return new KAction(i18n("&Quit"), "exit",
                        KStdAccel::key(KStdAccel::Quit), recvr, slot, parent,
@@ -212,7 +233,7 @@ KAction *KStdGameAction::quit(const QObject *recvr, const char *slot,
 }
 
 KAction *KStdGameAction::repeat(const QObject *recvr, const char *slot,
-                                                  QObject *parent, const char *name )
+                                                  KActionCollection *parent, const char *name )
 {
     return new KAction(i18n("Repeat"), /*0,*/// hm do we have a suitable icon for this?
 //                       KStdAccel::key(KStdAccel::Redo), recvr, slot, parent,
@@ -221,7 +242,7 @@ KAction *KStdGameAction::repeat(const QObject *recvr, const char *slot,
 }
 
 KAction *KStdGameAction::undo(const QObject *recvr, const char *slot,
-                                                  QObject *parent, const char *name )
+                                                  KActionCollection *parent, const char *name )
 {
     return new KAction(i18n("Und&o"), "undo",
                        KStdAccel::key(KStdAccel::Undo), recvr, slot, parent,
@@ -229,15 +250,23 @@ KAction *KStdGameAction::undo(const QObject *recvr, const char *slot,
 }
 
 KAction *KStdGameAction::redo(const QObject *recvr, const char *slot,
-                                                  QObject *parent, const char *name )
+                                                  KActionCollection *parent, const char *name )
 {
     return new KAction(i18n("Re&do"), "redo",
                        KStdAccel::key(KStdAccel::Redo), recvr, slot, parent,
                        name ? name : stdName(Redo));
 }
 
+KAction *KStdGameAction::roll(const QObject *recvr, const char *slot,
+                                                  KActionCollection *parent, const char *name )
+{
+    return new KAction(i18n("Roll"), "roll",
+                       0, recvr, slot, parent,
+                       name ? name : stdName(Roll));
+}
+
 KAction *KStdGameAction::endTurn(const QObject *recvr, const char *slot,
-                                                  QObject *parent, const char *name )
+                                                  KActionCollection *parent, const char *name )
 {
     return new KAction(i18n("End Turn"), "stop",
                        0, recvr, slot, parent,
@@ -245,10 +274,10 @@ KAction *KStdGameAction::endTurn(const QObject *recvr, const char *slot,
 }
 
 KAction *KStdGameAction::carddecks(const QObject *recvr, const char *slot,
-                                                  QObject *parent, const char *name )
+                                                  KActionCollection *parent, const char *name )
 {
 //AB: maybe we need an icon?
-    return new KAction(i18n("Configure &Carddecks"), 
+    return new KAction(i18n("Configure &Carddecks..."), 
                        0, recvr, slot, parent,
                        name ? name : stdName(Carddecks));
 }
