@@ -22,7 +22,7 @@
 #include <qprogressdialog.h>
 
 // include files for KDE
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
@@ -32,6 +32,7 @@
 #include <khelpmenu.h>
 #include <kstdaction.h>
 #include <kaction.h>
+#include <kdebug.h>
 
 
 // application specific includes
@@ -47,6 +48,7 @@
 
 
 #include <stdlib.h>
+#include <kstatusbar.h>
 
 #define ACTION(x)   (actionCollection()->action(x))
 #define ID_STATUS_MSG               1003
@@ -192,7 +194,7 @@ void LSkatApp::initGUI()
   ACTION("game_exit")->setStatusText(i18n("Exiting..."));
   ACTION("game_exit")->setWhatsThis(i18n("Quits the program."));
 
-  (void)new KToggleAction(i18n("&Statusbar"),0,this,SLOT(slotViewStatusBar()),
+  (void)new KToggleAction(i18n("&Show Statusbar"),0,this,SLOT(slotViewStatusBar()),
                       actionCollection(), "show_statusbar");
   ACTION("show_statusbar")->setStatusText(i18n("Toggle the statusbar..."));
   ACTION("show_statusbar")->setWhatsThis(i18n("Toggle the statusbar..."));
@@ -206,7 +208,7 @@ void LSkatApp::initGUI()
   list.append(i18n("Player &2"));
   ((KSelectAction *)ACTION("startplayer"))->setItems(list);
 
-  (void)new KSelectAction(i18n("Player &1 played by"),0,this,SLOT(slotPlayer1By()),
+  (void)new KSelectAction(i18n("Player &1 Played By"),0,this,SLOT(slotPlayer1By()),
                       actionCollection(), "player1");
   ACTION("player1")->setStatusText(i18n("Changing who plays player 1..."));
   ACTION("player1")->setWhatsThis(i18n("Changing who plays player 1..."));
@@ -215,7 +217,7 @@ void LSkatApp::initGUI()
   list.append(i18n("&Computer"));
   list.append(i18n("&Remote"));
   ((KSelectAction *)ACTION("player1"))->setItems(list);
-  (void)new KSelectAction(i18n("Player &2 played by"),0,this,SLOT(slotPlayer2By()),
+  (void)new KSelectAction(i18n("Player &2 Played By"),0,this,SLOT(slotPlayer2By()),
                       actionCollection(), "player2");
   ACTION("player1")->setStatusText(i18n("Changing who plays player 2..."));
   ACTION("player1")->setWhatsThis(i18n("Changing who plays player 2..."));
@@ -409,8 +411,8 @@ void LSkatApp::slotFileStatistics()
 {
    QString message;
 
-   message=i18n("Do you really want to clear the all time\n"
-                "statistical data?\n");
+   message=i18n("Do you really want to clear the all time "
+                "statistical data?");
 
   if (KMessageBox::Yes==KMessageBox::questionYesNo(this,message))
   {
@@ -479,19 +481,9 @@ void LSkatApp::slotFileEnd()
 void LSkatApp::slotFileQuit()
 {
   saveOptions();
-  // close the first window, the list makes the next one the first again.
-  // This ensures that queryClose() is called on each window to ask for closing
-  KMainWindow* w;
-  if(memberList)
-  {
-    for(w=memberList->first(); w!=0; w=memberList->first())
-    {
-      // only close the window if the closeEvent is accepted. If the user presses Cancel on the saveModified() dialog,
-      // the window and the application stay open.
-      if(w && !w->close())
-          break;
-    }
-  }
+  if (view) view->close();
+  close();
+  kdDebug() << "slotFileQuit done"<<endl;
 }
 
 
@@ -697,18 +689,18 @@ void LSkatApp::NewGame()
   if (!res)
   {
     KMessageBox::error(this,
-      i18n("Cannot start player 1. Maybe the network connection\n"
-           "failed or the computer player process file is not\n"
-           "found.\n"));
+      i18n("Cannot start player 1. Maybe the network connection "
+           "failed or the computer player process file is not "
+           "found."));
     return ;
   }
   res=MakeInputDevice(1);
   if (!res)
   {
     KMessageBox::error(this,
-      i18n("Cannot start player 2. Maybe the network connection\n"
-           "failed or the computer player process file is not\n"
-           "found.\n"));
+      i18n("Cannot start player 2. Maybe the network connection "
+           "failed or the computer player process file is not "
+           "found."));
     return ;
   }
   // Remote game is started when receiving the start mesage .. not here!
